@@ -9,20 +9,32 @@
  * @global Input $INPUT
  */
 
+use dokuwiki\Cache\Cache;
+use dokuwiki\ChangeLog\MediaChangeLog;
+use dokuwiki\ChangeLog\PageChangeLog;
+use dokuwiki\Extension\AuthPlugin;
+use dokuwiki\Extension\Event;
+
 if(!defined('DOKU_INC')) define('DOKU_INC', dirname(__FILE__).'/');
 require_once(DOKU_INC.'inc/init.php');
 
 //close session
 session_write_close();
 
+//feed disabled?
+if(!actionOK('rss')) {
+    http_status(404);
+    echo '<error>RSS feed is disabled.</error>';
+    exit;
+}
+
 // get params
 $opt = rss_parseOptions();
 
 // the feed is dynamic - we need a cache for each combo
 // (but most people just use the default feed so it's still effective)
-$cache = getCacheName(join('', array_values($opt)).$_SERVER['REMOTE_USER'], '.feed');
-$key   = join('', array_values($opt)).$_SERVER['REMOTE_USER'];
-$cache = new cache($key, '.feed');
+$key   = join('', array_values($opt)).'$'.$_SERVER['REMOTE_USER'].'$'.$_SERVER['HTTP_HOST'].$_SERVER['SERVER_PORT'];
+$cache = new Cache($key, '.feed');
 
 // prepare cache depends
 $depends['files'] = getConfigFiles('main');
@@ -36,7 +48,7 @@ header('Pragma: public');
 header('Content-Type: application/xml; charset=utf-8');
 header('X-Robots-Tag: noindex');
 if($cache->useCache($depends)) {
-    http_conditionalRequest($cache->_time);
+    http_conditionalRequest($cache->getTime());
     if($conf['allowdebug']) header("X-CacheUsed: $cache->cache");
     print $cache->retrieveCache();
     exit;
@@ -45,7 +57,7 @@ if($cache->useCache($depends)) {
 }
 
 // create new feed
-$rss                 = new DokuWikiFeedCreator();
+$rss                 = new UniversalFeedCreator();
 $rss->title          = $conf['title'].(($opt['namespace']) ? ' '.$opt['namespace'] : '');
 $rss->link           = DOKU_URL;
 $rss->syndicationURL = DOKU_URL.'feed.php';
@@ -70,7 +82,7 @@ if(isset($modes[$opt['feed_mode']])) {
         'opt'  => &$opt,
         'data' => &$data,
     );
-    $event     = new Doku_Event('FEED_MODE_UNKNOWN', $eventData);
+    $event     = new Event('FEED_MODE_UNKNOWN', $eventData);
     if($event->advise_before(true)) {
         echo sprintf('<error>Unknown feed mode %s</error>', hsc($opt['feed_mode']));
         exit;
@@ -79,7 +91,7 @@ if(isset($modes[$opt['feed_mode']])) {
 }
 
 rss_buildItems($rss, $data, $opt);
-$feed = $rss->createFeed($opt['feed_type'], 'utf-8');
+$feed = $rss->createFeed($opt['feed_type']);
 
 // save cachefile
 $cache->storeCache($feed);
@@ -121,26 +133,30 @@ function rss_parseOptions() {
                 'items'        => array('int', 'num', $conf['recent']),
                 // Boolean, only used in rc mode
                 'show_minor'   => array('bool', 'minor', false),
+                // Boolean, only used in rc mode
+                'only_new'     => array('bool', 'onlynewpages', false),
+                // String, only used in list mode
+                'sort'         => array('str', 'sort', 'natural'),
                 // String, only used in search mode
                 'search_query' => array('str', 'q', null),
                 // One of: pages, media, both
                 'content_type' => array('str', 'view', $conf['rss_media'])
 
             ) as $name => $val) {
-        $opt[$name] = $INPUT->$val[0]($val[1], $val[2], true);
+        $opt[$name] = $INPUT->{$val[0]}($val[1], $val[2], true);
     }
 
     $opt['items']      = max(0, (int) $opt['items']);
     $opt['show_minor'] = (bool) $opt['show_minor'];
+    $opt['only_new']   = (bool) $opt['only_new'];
+    $opt['sort'] = valid_input_set('sort', array('default' => 'natural', 'date'), $opt);
 
     $opt['guardmail'] = ($conf['mailguard'] != '' && $conf['mailguard'] != 'none');
 
-    $type = valid_input_set(
-        'type', array(
-                     'rss', 'rss2', 'atom', 'atom1', 'rss1',
-                     'default' => $conf['rss_type']
-                ),
-        $_REQUEST
+    $type = $INPUT->valid(
+        'type',
+        array( 'rss', 'rss2', 'atom', 'atom1', 'rss1'),
+        $conf['rss_type']
     );
     switch($type) {
         case 'rss':
@@ -167,7 +183,7 @@ function rss_parseOptions() {
     $eventData = array(
         'opt' => &$opt,
     );
-    trigger_event('FEED_OPTS_POSTPROCESS', $eventData);
+    Event::createAndTrigger('FEED_OPTS_POSTPROCESS', $eventData);
     return $opt;
 }
 
@@ -182,7 +198,7 @@ function rss_parseOptions() {
 function rss_buildItems(&$rss, &$data, $opt) {
     global $conf;
     global $lang;
-    /* @var auth_basic $auth */
+    /* @var AuthPlugin $auth */
     global $auth;
 
     $eventData = array(
@@ -190,7 +206,7 @@ function rss_buildItems(&$rss, &$data, $opt) {
         'data' => &$data,
         'opt'  => &$opt,
     );
-    $event     = new Doku_Event('FEED_DATA_PROCESS', $eventData);
+    $event     = new Event('FEED_DATA_PROCESS', $eventData);
     if($event->advise_before(false)) {
         foreach($data as $ditem) {
             if(!is_array($ditem)) {
@@ -209,12 +225,14 @@ function rss_buildItems(&$rss, &$data, $opt) {
             // add date
             if($ditem['date']) {
                 $date = $ditem['date'];
+            } elseif ($ditem['media']) {
+                $date = @filemtime(mediaFN($id));
+            } elseif (file_exists(wikiFN($id))) {
+                $date = @filemtime(wikiFN($id));
             } elseif($meta['date']['modified']) {
                 $date = $meta['date']['modified'];
-            } else if ($ditem['media']) {
-                $date = @filemtime(mediaFN($id));
             } else {
-                $date = @filemtime(wikiFN($id));
+                $date = 0;
             }
             if($date) $item->date = date('r', $date);
 
@@ -240,7 +258,7 @@ function rss_buildItems(&$rss, &$data, $opt) {
                             ), '&', true
                         );
                     } else {
-                        $item->link = wl($id, 'rev='.$date, true, '&', true);
+                        $item->link = wl($id, 'rev='.$date, true, '&');
                     }
                     break;
                 case 'rev':
@@ -291,18 +309,19 @@ function rss_buildItems(&$rss, &$data, $opt) {
                 case 'diff':
                 case 'htmldiff':
                     if($ditem['media']) {
-                        $revs  = getRevisions($id, 0, 1, 8192, true);
+                        $medialog = new MediaChangeLog($id);
+                        $revs  = $medialog->getRevisions(0, 1);
                         $rev   = $revs[0];
                         $src_r = '';
                         $src_l = '';
 
-                        if($size = media_image_preview_size($id, false, new JpegMeta(mediaFN($id)), 300)) {
-                            $more  = 'w='.$size[0].'&h='.$size[1].'t='.@filemtime(mediaFN($id));
-                            $src_r = ml($id, $more);
+                        if($size = media_image_preview_size($id, '', new JpegMeta(mediaFN($id)), 300)) {
+                            $more  = 'w='.$size[0].'&h='.$size[1].'&t='.@filemtime(mediaFN($id));
+                            $src_r = ml($id, $more, true, '&amp;', true);
                         }
                         if($rev && $size = media_image_preview_size($id, $rev, new JpegMeta(mediaFN($id, $rev)), 300)) {
                             $more  = 'rev='.$rev.'&w='.$size[0].'&h='.$size[1];
-                            $src_l = ml($id, $more);
+                            $src_l = ml($id, $more, true, '&amp;', true);
                         }
                         $content = '';
                         if($src_r) {
@@ -316,18 +335,20 @@ function rss_buildItems(&$rss, &$data, $opt) {
 
                     } else {
                         require_once(DOKU_INC.'inc/DifferenceEngine.php');
-                        $revs = getRevisions($id, 0, 1);
+                        $pagelog = new PageChangeLog($id);
+                        $revs = $pagelog->getRevisions(0, 1);
                         $rev  = $revs[0];
 
                         if($rev) {
-                            $df = new Diff(explode("\n", htmlspecialchars(rawWiki($id, $rev))),
-                                           explode("\n", htmlspecialchars(rawWiki($id, ''))));
+                            $df = new Diff(explode("\n", rawWiki($id, $rev)),
+                                           explode("\n", rawWiki($id, '')));
                         } else {
                             $df = new Diff(array(''),
-                                           explode("\n", htmlspecialchars(rawWiki($id, ''))));
+                                           explode("\n", rawWiki($id, '')));
                         }
 
                         if($opt['item_content'] == 'htmldiff') {
+                            // note: no need to escape diff output, TableDiffFormatter provides 'safe' html
                             $tdf     = new TableDiffFormatter();
                             $content = '<table>';
                             $content .= '<tr><th colspan="2" width="50%">'.$rev.'</th>';
@@ -335,22 +356,27 @@ function rss_buildItems(&$rss, &$data, $opt) {
                             $content .= $tdf->format($df);
                             $content .= '</table>';
                         } else {
+                            // note: diff output must be escaped, UnifiedDiffFormatter provides plain text
                             $udf     = new UnifiedDiffFormatter();
-                            $content = "<pre>\n".$udf->format($df)."\n</pre>";
+                            $content = "<pre>\n".hsc($udf->format($df))."\n</pre>";
                         }
                     }
                     break;
                 case 'html':
                     if($ditem['media']) {
-                        if($size = media_image_preview_size($id, false, new JpegMeta(mediaFN($id)))) {
-                            $more    = 'w='.$size[0].'&h='.$size[1].'t='.@filemtime(mediaFN($id));
-                            $src     = ml($id, $more);
+                        if($size = media_image_preview_size($id, '', new JpegMeta(mediaFN($id)))) {
+                            $more    = 'w='.$size[0].'&h='.$size[1].'&t='.@filemtime(mediaFN($id));
+                            $src     = ml($id, $more, true, '&amp;', true);
                             $content = '<img src="'.$src.'" alt="'.$id.'" />';
                         } else {
                             $content = '';
                         }
                     } else {
-                        $content = p_wiki_xhtml($id, $date, false);
+                        if (@filemtime(wikiFN($id)) === $date) {
+                            $content = p_wiki_xhtml($id, '', false);
+                        } else {
+                            $content = p_wiki_xhtml($id, $date, false);
+                        }
                         // no TOC in feeds
                         $content = preg_replace('/(<!-- TOC START -->).*(<!-- TOC END -->)/s', '', $content);
 
@@ -369,9 +395,9 @@ function rss_buildItems(&$rss, &$data, $opt) {
                 case 'abstract':
                 default:
                     if($ditem['media']) {
-                        if($size = media_image_preview_size($id, false, new JpegMeta(mediaFN($id)))) {
-                            $more    = 'w='.$size[0].'&h='.$size[1].'t='.@filemtime(mediaFN($id));
-                            $src     = ml($id, $more);
+                        if($size = media_image_preview_size($id, '', new JpegMeta(mediaFN($id)))) {
+                            $more    = 'w='.$size[0].'&h='.$size[1].'&t='.@filemtime(mediaFN($id));
+                            $src     = ml($id, $more, true, '&amp;', true);
                             $content = '<img src="'.$src.'" alt="'.$id.'" />';
                         } else {
                             $content = '';
@@ -385,33 +411,30 @@ function rss_buildItems(&$rss, &$data, $opt) {
             // add user
             # FIXME should the user be pulled from metadata as well?
             $user         = @$ditem['user']; // the @ spares time repeating lookup
-            $item->author = '';
-            if($user && $conf['useacl'] && $auth) {
-                $userInfo = $auth->getUserData($user);
-                if($userInfo) {
-                    switch($conf['showuseras']) {
-                        case 'username':
-                            $item->author = $userInfo['name'];
-                            break;
-                        default:
-                            $item->author = $user;
-                            break;
-                    }
-                } else {
-                    $item->author = $user;
-                }
-                if($userInfo && !$opt['guardmail']) {
-                    $item->authorEmail = $userInfo['mail'];
-                } else {
-                    //cannot obfuscate because some RSS readers may check validity
-                    $item->authorEmail = $user.'@'.$ditem['ip'];
-                }
-            } elseif($user) {
-                // this happens when no ACL but some Apache auth is used
-                $item->author      = $user;
-                $item->authorEmail = $user.'@'.$ditem['ip'];
+            if(blank($user)) {
+                $item->author = 'Anonymous';
+                $item->authorEmail = 'anonymous@undisclosed.example.com';
             } else {
-                $item->authorEmail = 'anonymous@'.$ditem['ip'];
+                $item->author = $user;
+                $item->authorEmail = $user . '@undisclosed.example.com';
+
+                // get real user name if configured
+                if($conf['useacl'] && $auth) {
+                    $userInfo = $auth->getUserData($user);
+                    if($userInfo) {
+                        switch($conf['showuseras']) {
+                            case 'username':
+                            case 'username_link':
+                                $item->author = $userInfo['name'];
+                                break;
+                            default:
+                                $item->author = $user;
+                                break;
+                        }
+                    } else {
+                        $item->author = $user;
+                    }
+                }
             }
 
             // add category
@@ -429,7 +452,7 @@ function rss_buildItems(&$rss, &$data, $opt) {
                 'ditem' => &$ditem,
                 'rss'   => &$rss
             );
-            $evt    = new Doku_Event('FEED_ITEM_ADD', $evdata);
+            $evt    = new Event('FEED_ITEM_ADD', $evdata);
             if($evt->advise_before()) {
                 $rss->addItem($item);
             }
@@ -446,8 +469,10 @@ function rss_buildItems(&$rss, &$data, $opt) {
  */
 function rssRecentChanges($opt) {
     global $conf;
-    $flags = RECENTS_SKIP_DELETED;
+    $flags = 0;
+    if(!$conf['rss_show_deleted']) $flags += RECENTS_SKIP_DELETED;
     if(!$opt['show_minor']) $flags += RECENTS_SKIP_MINORS;
+    if($opt['only_new']) $flags += RECENTS_ONLY_CREATION;
     if($opt['content_type'] == 'media' && $conf['mediarevisions']) $flags += RECENTS_MEDIA_CHANGES;
     if($opt['content_type'] == 'both' && $conf['mediarevisions']) $flags += RECENTS_MEDIA_PAGES_MIXED;
 
@@ -465,11 +490,15 @@ function rssListNamespace($opt) {
     global $conf;
 
     $ns = ':'.cleanID($opt['namespace']);
-    $ns = str_replace(':', '/', $ns);
+    $ns = utf8_encodeFN(str_replace(':', '/', $ns));
 
     $data = array();
-    sort($data);
-    search($data, $conf['datadir'], 'search_list', '', $ns);
+    $search_opts = array(
+        'depth' => 1,
+        'pagesonly' => true,
+        'listfiles' => true
+    );
+    search($data, $conf['datadir'], 'search_universal', $search_opts, $ns, $lvl = 1, $opt['sort']);
 
     return $data;
 }
