@@ -5,6 +5,7 @@
  *
  * All DokuWiki commandline scripts should inherit from this class and implement the abstract methods.
  *
+ * @deprecated 2017-11-10
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 abstract class DokuCLI {
@@ -25,6 +26,9 @@ abstract class DokuCLI {
 
         $this->options = new DokuCLI_Options();
         $this->colors  = new DokuCLI_Colors();
+
+        dbg_deprecated('use \splitbrain\phpcli\CLI instead');
+        $this->error('DokuCLI is deprecated, use \splitbrain\phpcli\CLI instead.');
     }
 
     /**
@@ -62,7 +66,7 @@ abstract class DokuCLI {
         );
         $this->options->registerOption(
             'help',
-            'Display this help screen and exit immeadiately.',
+            'Display this help screen and exit immediately.',
             'h'
         );
 
@@ -108,7 +112,7 @@ abstract class DokuCLI {
     /**
      * Print an error message
      *
-     * @param $string
+     * @param string $string
      */
     public function error($string) {
         $this->colors->ptln("E: $string", 'red', STDERR);
@@ -117,7 +121,7 @@ abstract class DokuCLI {
     /**
      * Print a success message
      *
-     * @param $string
+     * @param string $string
      */
     public function success($string) {
         $this->colors->ptln("S: $string", 'green', STDERR);
@@ -126,7 +130,7 @@ abstract class DokuCLI {
     /**
      * Print an info message
      *
-     * @param $string
+     * @param string $string
      */
     public function info($string) {
         $this->colors->ptln("I: $string", 'cyan', STDERR);
@@ -199,8 +203,8 @@ class DokuCLI_Colors {
     /**
      * Convenience function to print a line in a given color
      *
-     * @param          $line
-     * @param          $color
+     * @param string   $line
+     * @param string   $color
      * @param resource $channel
      */
     public function ptln($line, $color, $channel = STDOUT) {
@@ -398,13 +402,13 @@ class DokuCLI_Options {
             }
 
             // first non-option
-            if($arg{0} != '-') {
+            if($arg[0] != '-') {
                 $non_opts = array_merge($non_opts, array_slice($this->args, $i));
                 break;
             }
 
             // long option
-            if(strlen($arg) > 1 && $arg{1} == '-') {
+            if(strlen($arg) > 1 && $arg[1] == '-') {
                 list($opt, $val) = explode('=', substr($arg, 2), 2);
 
                 if(!isset($this->setup[$this->command]['opts'][$opt])) {
@@ -470,8 +474,8 @@ class DokuCLI_Options {
      * Can only be used after parseOptions() has been run
      *
      * @param string $option
-     * @param mixed  $default what to return if the option was not set
-     * @return mixed
+     * @param bool|string $default what to return if the option was not set
+     * @return bool|string
      */
     public function getOpt($option, $default = false) {
         if(isset($this->options[$option])) return $this->options[$option];
@@ -593,8 +597,8 @@ class DokuCLI_Options {
     /**
      * Displays text in multiple word wrapped columns
      *
-     * @param array $widths list of column widths (in characters)
-     * @param array $texts  list of texts for each column
+     * @param int[]    $widths list of column widths (in characters)
+     * @param string[] $texts  list of texts for each column
      * @return string
      */
     private function tableFormat($widths, $texts) {
@@ -640,6 +644,11 @@ class DokuCLI_Exception extends Exception {
     const E_OPT_ABIGUOUS = 4; //Option abiguous
     const E_ARG_READ = 5; //Could not read argv
 
+    /**
+     * @param string    $message     The Exception message to throw.
+     * @param int       $code        The Exception code
+     * @param Exception $previous    The previous exception used for the exception chaining.
+     */
     public function __construct($message = "", $code = 0, Exception $previous = null) {
         if(!$code) $code = DokuCLI_Exception::E_ANY;
         parent::__construct($message, $code, $previous);
