@@ -3,6 +3,7 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author Salif Mehmed <salif13mehmed@gmail.com>
  * @author Nikolay Vladimirov <nikolay@vladimiroff.com>
  * @author Viktor Usunov <usun0v@mail.bg>
  * @author Kiril <neohidra@gmail.com>
@@ -67,45 +68,6 @@ $lang['badpassconfirm']        = 'За съжаление паролата е г
 $lang['minoredit']             = 'Промените са незначителни';
 $lang['draftdate']             = 'Черновата е автоматично записана на';
 $lang['nosecedit']             = 'Страницата бе междувременно променена, презареждане на страницата поради неактуална информация.';
-$lang['searchcreatepage']      = 'Ако не намирате каквото сте търсили, може да създадете или редактирате страница, кръстена на вашата заявка, чрез съответния бутон.';
-$lang['regmissing']            = 'Моля, попълнете всички полета.';
-$lang['reguexists']            = 'Вече съществува потребител с избраното име.';
-$lang['regsuccess']            = 'Потребителят е създаден, а паролата е пратена по електронната поща.';
-$lang['regsuccess2']           = 'Потребителят е създаден.';
-$lang['regfail']               = 'Потребителят не може да бъде създаден.';
-$lang['regmailfail']           = 'Изглежда, че има проблем с пращането на писмото с паролата. Моля, свържете се с администратора!';
-$lang['regbadmail']            = 'Въведеният адрес изглежда невалиден - ако мислите, че това е грешка, свържете се с администратора.';
-$lang['regbadpass']            = 'Двете въведени пароли не съвпадат, моля опитайте отново.';
-$lang['regpwmail']             = 'Паролата ви за DokuWiki';
-$lang['reghere']               = 'Все още нямате профил? Направете си';
-$lang['profna']                = 'Wiki-то не поддържа промяна на профила';
-$lang['profnochange']          = 'Няма промени.';
-$lang['profnoempty']           = 'Въвеждането на име и имейл е задължително';
-$lang['profchanged']           = 'Потребителският профил е обновен успешно.';
-$lang['profnodelete']          = 'Изтриването на потребители в това wiki не е възможно';
-$lang['profdeleteuser']        = 'Изтриване на профила';
-$lang['profdeleted']           = 'Вашият профил е премахнат от това wiki ';
-$lang['profconfdelete']        = 'Искам да изтрия профила си от това wiki. <br/>  Веднъж изтрит, профилът не може да бъде възстановен!';
-$lang['profconfdeletemissing'] = 'Не сте поставили отметка в кутията потвърждение';
-$lang['proffail']              = 'Потребителският профил не може да бъде актуализиран.';
-$lang['pwdforget']             = 'Забравили сте паролата си? Получете нова';
-$lang['resendna']              = 'Wiki-то не поддържа повторно пращане на паролата.';
-$lang['resendpwd']             = 'Задаване на нова парола за';
-$lang['resendpwdmissing']      = 'Моля, попълнете всички полета.';
-$lang['resendpwdnouser']       = 'Потребителят не е намерен в базата от данни.';
-$lang['resendpwdbadauth']      = 'Кодът за потвърждение е невалиден. Проверете дали сте използвали целия линк за потвърждение.';
-$lang['resendpwdconfirm']      = 'Линк за потвърждение е пратен по електронната поща.';
-$lang['resendpwdsuccess']      = 'Новата ви паролата е пратена по електронната поща.';
-$lang['license']               = 'Ако не е посочено друго, съдържанието на Wiki-то е лицензирано под следния лиценз:';
-$lang['licenseok']             = 'Бележка: Редактирайки страницата, Вие се съгласявате да лицензирате промените (които сте направили) под следния лиценз:';
-$lang['searchmedia']           = 'Търсене на файл: ';
-$lang['searchmedia_in']        = 'Търсене в %s';
-$lang['txt_upload']            = 'Изберете файл за качване:';
-$lang['txt_filename']          = 'Качи като (незадължително):';
-$lang['txt_overwrt']           = 'Презапиши съществуващите файлове';
-$lang['maxuploadsize']         = 'Макс. размер за отделните файлове е %s.';
-$lang['lockedby']              = 'В момента е заключена от:';
-$lang['lockexpire']            = 'Ще бъде отключена на:';
 $lang['js']['willexpire']      = 'Страницата ще бъде отключена за редактиране след минута.\nЗа предотвратяване на конфликти, ползвайте бутона "Преглед", за рестартиране на брояча за заключване.';
 $lang['js']['notsavedyet']     = 'Незаписаните промени ще бъдат загубени. Желаете ли да продължите?';
 $lang['js']['searchmedia']     = 'Търсене на файлове';
@@ -147,6 +109,51 @@ $lang['js']['media_done_btn']  = 'Готово';
 $lang['js']['media_drop']      = 'Влачете и пуснете файлове тук, за да бъдат качени';
 $lang['js']['media_cancel']    = 'премахване';
 $lang['js']['media_overwrt']   = 'Презапиши съществуващите файлове';
+$lang['search_starts_with']    = 'започва с';
+$lang['search_ends_with']      = 'завършва с';
+$lang['search_contains']       = 'съдържа';
+$lang['search_any_time']       = 'по всяко време';
+$lang['search_past_7_days']    = 'миналата седмица';
+$lang['search_past_month']     = 'миналия месец';
+$lang['search_past_year']      = 'миналата година';
+$lang['regmissing']            = 'Моля, попълнете всички полета.';
+$lang['reguexists']            = 'Вече съществува потребител с избраното име.';
+$lang['regsuccess']            = 'Потребителят е създаден, а паролата е пратена по електронната поща.';
+$lang['regsuccess2']           = 'Потребителят е създаден.';
+$lang['regfail']               = 'Потребителят не може да бъде създаден.';
+$lang['regmailfail']           = 'Изглежда, че има проблем с пращането на писмото с паролата. Моля, свържете се с администратора!';
+$lang['regbadmail']            = 'Въведеният адрес изглежда невалиден - ако мислите, че това е грешка, свържете се с администратора.';
+$lang['regbadpass']            = 'Двете въведени пароли не съвпадат, моля опитайте отново.';
+$lang['regpwmail']             = 'Паролата ви за DokuWiki';
+$lang['reghere']               = 'Все още нямате профил? Направете си';
+$lang['profna']                = 'Wiki-то не поддържа промяна на профила';
+$lang['profnochange']          = 'Няма промени.';
+$lang['profnoempty']           = 'Въвеждането на име и имейл е задължително';
+$lang['profchanged']           = 'Потребителският профил е обновен успешно.';
+$lang['profnodelete']          = 'Изтриването на потребители в това wiki не е възможно';
+$lang['profdeleteuser']        = 'Изтриване на профила';
+$lang['profdeleted']           = 'Вашият профил е премахнат от това wiki ';
+$lang['profconfdelete']        = 'Искам да изтрия профила си от това wiki. <br/>  Веднъж изтрит, профилът не може да бъде възстановен!';
+$lang['profconfdeletemissing'] = 'Не сте поставили отметка в кутията потвърждение';
+$lang['proffail']              = 'Потребителският профил не може да бъде актуализиран.';
+$lang['pwdforget']             = 'Забравили сте паролата си? Получете нова';
+$lang['resendna']              = 'Wiki-то не поддържа повторно пращане на паролата.';
+$lang['resendpwd']             = 'Задаване на нова парола за';
+$lang['resendpwdmissing']      = 'Моля, попълнете всички полета.';
+$lang['resendpwdnouser']       = 'Потребителят не е намерен в базата от данни.';
+$lang['resendpwdbadauth']      = 'Кодът за потвърждение е невалиден. Проверете дали сте използвали целия линк за потвърждение.';
+$lang['resendpwdconfirm']      = 'Линк за потвърждение е пратен по електронната поща.';
+$lang['resendpwdsuccess']      = 'Новата ви паролата е пратена по електронната поща.';
+$lang['license']               = 'Ако не е посочено друго, съдържанието на Wiki-то е лицензирано под следния лиценз:';
+$lang['licenseok']             = 'Бележка: Редактирайки страницата, Вие се съгласявате да лицензирате промените (които сте направили) под следния лиценз:';
+$lang['searchmedia']           = 'Търсене на файл: ';
+$lang['searchmedia_in']        = 'Търсене в %s';
+$lang['txt_upload']            = 'Изберете файл за качване:';
+$lang['txt_filename']          = 'Качи като (незадължително):';
+$lang['txt_overwrt']           = 'Презапиши съществуващите файлове';
+$lang['maxuploadsize']         = 'Макс. размер за отделните файлове е %s.';
+$lang['lockedby']              = 'В момента е заключена от:';
+$lang['lockexpire']            = 'Ще бъде отключена на:';
 $lang['rssfailed']             = 'Възникна грешка при получаването на емисията: ';
 $lang['nothingfound']          = 'Нищо не е открито.';
 $lang['mediaselect']           = 'Файлове';
@@ -334,5 +341,5 @@ $lang['media_restore']         = 'Възстановяване на тази в
 $lang['currentns']             = 'Текущо именно пространство';
 $lang['searchresult']          = 'Резултати от търсенето';
 $lang['plainhtml']             = 'Обикновен HTML';
-$lang['email_signature_text'] = 'Писмото е генерирано от DokuWiki на адрес
+$lang['email_signature_text']  = 'Писмото е генерирано от DokuWiki на адрес
 @DOKUWIKIURL@';
