@@ -1,19 +1,30 @@
 <?php
+
 /**
- * Czech language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
+ * @author Petr Kajzar <petr.kajzar@lf1.cuni.cz>
+ * @author Aleksandr Selivanov <alexgearbox@yandex.ru>
+ * @author Robert Surý <rsurycz@seznam.cz>
+ * @author Martin Hořínek <hev@hev.cz>
+ * @author Jonáš Dyba <jonas.dyba@gmail.com>
  * @author Bohumir Zamecnik <bohumir@zamecnik.org>
  * @author Tomas Valenta <t.valenta@sh.cvut.cz>
- * @author Tomas Valenta <tomas@valenta.cz>
  * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
  * @author Marek Sacha <sachamar@fel.cvut.cz>
  * @author Lefty <lefty@multihost.cz>
  * @author Vojta Beran <xmamut@email.cz>
- * @author zbynek.krivka@seznam.cz
- * @author Bohumir Zamecnik <bohumir.zamecnik@gmail.com>
  * @author Jakub A. Těšínský (j@kub.cz)
- * @author mkucera66@seznam.cz
+ * @author mkucera66 <mkucera66@seznam.cz>
+ * @author Zbyněk Křivka <krivka@fit.vutbr.cz>
+ * @author Petr Klíma <qaxi@seznam.cz>
+ * @author Radovan Buroň <radovan@buron.cz>
+ * @author Viktor Zavadil <vzavadil@newps.cz>
+ * @author Jaroslav Lichtblau <jlichtblau@seznam.cz>
+ * @author Turkislav <turkislav@blabla.com>
+ * @author Daniel Slováček <danslo@danslo.cz>
+ * @author Martin Růžička <martinr@post.cz>
+ * @author Pavel Krupička <pajdacz@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -35,8 +46,8 @@ $lang['btn_older']             = 'starší >>';
 $lang['btn_revs']              = 'Starší verze';
 $lang['btn_recent']            = 'Poslední úpravy';
 $lang['btn_upload']            = 'Načíst';
-$lang['btn_cancel']            = 'Storno';
-$lang['btn_index']             = 'Index';
+$lang['btn_cancel']            = 'Zrušit';
+$lang['btn_index']             = 'Mapa stránek';
 $lang['btn_secedit']           = 'Upravit';
 $lang['btn_login']             = 'Přihlásit se';
 $lang['btn_logout']            = 'Odhlásit se';
@@ -45,8 +56,7 @@ $lang['btn_update']            = 'Aktualizovat';
 $lang['btn_delete']            = 'Vymazat';
 $lang['btn_back']              = 'Zpět';
 $lang['btn_backlink']          = 'Zpětné odkazy';
-$lang['btn_backtomedia']       = 'Zpět do Výběru dokumentu';
-$lang['btn_subscribe']         = 'Odebírat emailem změny stránky';
+$lang['btn_subscribe']         = 'Odebírat e-mailem změny stránky';
 $lang['btn_profile']           = 'Upravit profil';
 $lang['btn_reset']             = 'Reset';
 $lang['btn_resendpwd']         = 'Nastavit nové heslo';
@@ -57,51 +67,27 @@ $lang['btn_revert']            = 'Vrátit zpět';
 $lang['btn_register']          = 'Registrovat';
 $lang['btn_apply']             = 'Použít';
 $lang['btn_media']             = 'Správa médií';
-$lang['loggedinas']            = 'Přihlášen(a) jako';
+$lang['btn_deleteuser']        = 'Odstranit můj účet';
+$lang['btn_img_backto']        = 'Zpět na %s';
+$lang['btn_mediaManager']      = 'Zobrazit ve správě médií';
+$lang['loggedinas']            = 'Přihlášen(a) jako:';
 $lang['user']                  = 'Uživatelské jméno';
 $lang['pass']                  = 'Heslo';
 $lang['newpass']               = 'Nové heslo';
 $lang['oldpass']               = 'Současné heslo';
-$lang['passchk']               = 'ještě jednou';
-$lang['remember']              = 'Přihlásit se nastálo';
+$lang['passchk']               = 'Zopakovat';
+$lang['remember']              = 'Zapamatovat';
 $lang['fullname']              = 'Celé jméno';
 $lang['email']                 = 'E-mail';
 $lang['profile']               = 'Uživatelský profil';
 $lang['badlogin']              = 'Zadané uživatelské jméno a heslo není správně.';
+$lang['badpassconfirm']        = 'Bohužel špatné heslo';
 $lang['minoredit']             = 'Drobné změny';
 $lang['draftdate']             = 'Koncept automaticky uložen v';
 $lang['nosecedit']             = 'Stránka byla v mezičase změněna. Informace o sekci již nebylo platné, byla načtena celá stránka.';
-$lang['regmissing']            = 'Musíte vyplnit všechny údaje.';
-$lang['reguexists']            = 'Uživatel se stejným jménem už je zaregistrován.';
-$lang['regsuccess']            = 'Uživatelský účet byl vytvořen a heslo zasláno mailem.';
-$lang['regsuccess2']           = 'Uživatelský účet byl vytvořen.';
-$lang['regmailfail']           = 'Zdá se, že nastala chyba při posílání mailu s heslem. Zkuste kontaktovat správce.';
-$lang['regbadmail']            = 'Zadaná mailová adresa není platná. Pokud si myslíte, že to je špatně, zkuste kontaktovat správce.';
-$lang['regbadpass']            = 'Heslo nebylo zadáno dvakrát stejně, zkuste to prosím znovu.';
-$lang['regpwmail']             = 'Vaše heslo do systému DokuWiki';
-$lang['reghere']               = 'Nemáte uživatelský účet? Zřiďte si ho';
-$lang['profna']                = 'Tato wiki neumožňuje změnu profilu';
-$lang['profnochange']          = 'Žádné změny nebyly provedeny.';
-$lang['profnoempty']           = 'Nelze zadat prázdné jméno nebo mailová adresa.';
-$lang['profchanged']           = 'Uživatelský profil změněn.';
-$lang['pwdforget']             = 'Zapomněli jste heslo? Nechte si zaslat nové';
-$lang['resendna']              = 'Tato wiki neumožňuje zasílání nových hesel.';
-$lang['resendpwd']             = 'Nastavit nové heslo pro';
-$lang['resendpwdmissing']      = 'Musíte vyplnit všechny položky.';
-$lang['resendpwdnouser']       = 'Bohužel takový uživatel v systému není.';
-$lang['resendpwdbadauth']      = 'Autorizační kód není platný. Zadali jste opravdu celý odkaz na potvrzovací stránku?';
-$lang['resendpwdconfirm']      = 'Odkaz na potvrzovací stránku byl odeslán mailem.';
-$lang['resendpwdsuccess']      = 'Vaše nové heslo bylo odesláno emailem.';
-$lang['license']               = 'Kromě míst, kde je explicitně uvedeno jinak, je obsah této wiki licencován pod následující licencí:';
-$lang['licenseok']             = 'Poznámka: Tím, že editujete tuto stránku, souhlasíte, aby váš obsah byl licencován pod následující licencí:';
-$lang['searchmedia']           = 'Hledat jméno souboru:';
-$lang['searchmedia_in']        = 'Hledat v %s';
-$lang['txt_upload']            = 'Vyberte soubor jako přílohu';
-$lang['txt_filename']          = 'Wiki jméno (volitelné)';
-$lang['txt_overwrt']           = 'Přepsat existující soubor';
-$lang['maxuploadsize']         = 'Max. velikost souboru %s';
-$lang['lockedby']              = 'Právě zamknuto:';
-$lang['lockexpire']            = 'Zámek vyprší:';
+$lang['searchcreatepage']      = 'Pokud jste nenašli to, co jste hledali, můžete vytvořit nebo upravit stránku %s, pojmenovanou podle vašeho dotazu.';
+$lang['search_fullresults']    = 'Fulltextové výsledky';
+$lang['js']['search_toggle_tools'] = 'Zobrazit/skrýt vyhledávací nástroje';
 $lang['js']['willexpire']      = 'Váš zámek pro editaci za chvíli vyprší.\nAbyste předešli konfliktům, stiskněte tlačítko Náhled a zámek se prodlouží.';
 $lang['js']['notsavedyet']     = 'Jsou tu neuložené změny, které budou ztraceny.
 Chcete opravdu pokračovat?';
@@ -115,8 +101,8 @@ $lang['js']['mediasize']       = 'Velikost obrázku';
 $lang['js']['mediatarget']     = 'Cíl odkazu';
 $lang['js']['mediaclose']      = 'Zavřít';
 $lang['js']['mediainsert']     = 'Vložit';
-$lang['js']['mediadisplayimg'] = 'Ukázat obrázek';
-$lang['js']['mediadisplaylnk'] = 'Ukázat pouze odkaz';
+$lang['js']['mediadisplayimg'] = 'Zobrazit obrázek';
+$lang['js']['mediadisplaylnk'] = 'Zobrazit pouze odkaz';
 $lang['js']['mediasmall']      = 'Malá verze';
 $lang['js']['mediamedium']     = 'Střední verze';
 $lang['js']['medialarge']      = 'Velká verze';
@@ -145,15 +131,64 @@ $lang['js']['media_done_btn']  = 'Hotovo';
 $lang['js']['media_drop']      = 'Sem přetáhněte soubory pro nahrátí';
 $lang['js']['media_cancel']    = 'odstranit';
 $lang['js']['media_overwrt']   = 'Přepsat existující soubory';
+$lang['search_exact_match']    = 'Přesná shoda';
+$lang['search_starts_with']    = 'Začíná s';
+$lang['search_ends_with']      = 'Končí s';
+$lang['search_contains']       = 'Obsahuje';
+$lang['search_custom_match']   = 'Vlastní';
+$lang['search_any_ns']         = 'Jakýkoliv jmenný prostor';
+$lang['search_any_time']       = 'Jakýkoliv čas';
+$lang['search_past_7_days']    = 'Minulý týden';
+$lang['search_past_month']     = 'Minulý měsíc';
+$lang['search_past_year']      = 'Minulý rok';
+$lang['search_sort_by_hits']   = 'Řadit podle shody';
+$lang['search_sort_by_mtime']  = 'Řadit podle naposledy změněných';
+$lang['regmissing']            = 'Musíte vyplnit všechny údaje.';
+$lang['reguexists']            = 'Uživatel se stejným jménem už je zaregistrován.';
+$lang['regsuccess']            = 'Uživatelský účet byl vytvořen a heslo zasláno e-mailem.';
+$lang['regsuccess2']           = 'Uživatelský účet byl vytvořen.';
+$lang['regfail']               = 'Uživatelský profil nemohl být vytvořen.';
+$lang['regmailfail']           = 'Zdá se, že nastala chyba při posílání mailu s heslem. Zkuste kontaktovat správce.';
+$lang['regbadmail']            = 'Zadaná e-mailová adresa není platná. Pokud si myslíte, že to je špatně, zkuste kontaktovat správce.';
+$lang['regbadpass']            = 'Heslo nebylo zadáno dvakrát stejně, zkuste to prosím znovu.';
+$lang['regpwmail']             = 'Vaše heslo do systému DokuWiki';
+$lang['reghere']               = 'Nemáte uživatelský účet? Zřiďte si ho';
+$lang['profna']                = 'Tato wiki neumožňuje změnu profilu';
+$lang['profnochange']          = 'Žádné změny nebyly provedeny.';
+$lang['profnoempty']           = 'Nelze vynechat jméno nebo e-mailovou adresu.';
+$lang['profchanged']           = 'Uživatelský profil změněn.';
+$lang['profnodelete']          = 'Tato wiki nepodporuje mazání uživatelů';
+$lang['profdeleteuser']        = 'Smazat účet';
+$lang['profdeleted']           = 'Váš uživatelský účet byl z této wiki smazán';
+$lang['profconfdelete']        = 'Chci smazat můj účet z této wiki. <br/> Tato akce je nevratná.';
+$lang['profconfdeletemissing'] = 'Potvrzovací tlačítko nezaškrtnuto';
+$lang['proffail']              = 'Uživatelský profil nebyl aktualizován.';
+$lang['pwdforget']             = 'Zapomněli jste heslo? Nechte si zaslat nové';
+$lang['resendna']              = 'Tato wiki neumožňuje zasílání nových hesel.';
+$lang['resendpwd']             = 'Nastavit nové heslo pro';
+$lang['resendpwdmissing']      = 'Musíte vyplnit všechny položky.';
+$lang['resendpwdnouser']       = 'Bohužel takový uživatel v systému není.';
+$lang['resendpwdbadauth']      = 'Tento autorizační kód není platný. Zadali jste opravdu celý odkaz na potvrzovací stránku?';
+$lang['resendpwdconfirm']      = 'Odkaz na potvrzovací stránku byl odeslán e-mailem.';
+$lang['resendpwdsuccess']      = 'Vaše nové heslo bylo odesláno e-mailem.';
+$lang['license']               = 'Kromě míst, kde je explicitně uvedeno jinak, je obsah této wiki licencován pod následující licencí:';
+$lang['licenseok']             = 'Poznámka: Tím, že editujete tuto stránku, souhlasíte, aby váš obsah byl licencován pod následující licencí:';
+$lang['searchmedia']           = 'Hledat jméno souboru:';
+$lang['searchmedia_in']        = 'Hledat v %s';
+$lang['txt_upload']            = 'Vyberte soubor jako přílohu:';
+$lang['txt_filename']          = 'Wiki jméno (volitelné):';
+$lang['txt_overwrt']           = 'Přepsat existující soubor';
+$lang['maxuploadsize']         = 'Max. velikost souboru %s';
+$lang['lockedby']              = 'Právě zamknuto:';
+$lang['lockexpire']            = 'Zámek vyprší:';
 $lang['rssfailed']             = 'Nastala chyba při vytváření tohoto RSS: ';
 $lang['nothingfound']          = 'Nic nenalezeno.';
 $lang['mediaselect']           = 'Výběr dokumentu';
-$lang['fileupload']            = 'Načtení dokumentu';
 $lang['uploadsucc']            = 'Přenos proběhl v pořádku';
 $lang['uploadfail']            = 'Chyba při načítání. Možná kvůli špatně nastaveným právům?';
 $lang['uploadwrong']           = 'Načtení souboru s takovouto příponou není dovoleno.';
 $lang['uploadexist']           = 'Soubor už existuje, necháme ho být.';
-$lang['uploadbadcontent']      = 'Obsah načteného dokumentu %s neodpovídá jeho příponě.';
+$lang['uploadbadcontent']      = 'Nahraný obsah neodpovídá jeho příponě souboru %s.';
 $lang['uploadspam']            = 'Načtený dokument byl odmítnut, je na spamovém blacklistu.';
 $lang['uploadxss']             = 'Načtený dokument byl odmítnut. Zdá se, že obsahuje škodlivé věci.';
 $lang['uploadsize']            = 'Nahraný soubor byl příliš velký (max. %s)';
@@ -182,10 +217,15 @@ $lang['difflink']              = 'Odkaz na výstup diff';
 $lang['diff_type']             = 'Zobrazit rozdíly:';
 $lang['diff_inline']           = 'Vložené';
 $lang['diff_side']             = 'Přidané';
+$lang['diffprevrev']           = 'Předchozí verze';
+$lang['diffnextrev']           = 'Následující verze';
+$lang['difflastrev']           = 'Poslední revize';
+$lang['diffbothprevrev']       = 'Obě strany předchozí revize';
+$lang['diffbothnextrev']       = 'Obě strany příští revize';
 $lang['line']                  = 'Řádek';
-$lang['breadcrumb']            = 'Historie';
-$lang['youarehere']            = 'Umístění';
-$lang['lastmod']               = 'Poslední úprava';
+$lang['breadcrumb']            = 'Historie:';
+$lang['youarehere']            = 'Umístění:';
+$lang['lastmod']               = 'Poslední úprava:';
 $lang['by']                    = 'autor:';
 $lang['deleted']               = 'odstraněno';
 $lang['created']               = 'vytvořeno';
@@ -204,7 +244,7 @@ $lang['mail_newpage']          = 'nová stránka:';
 $lang['mail_changed']          = 'změna stránky:';
 $lang['mail_subscribe_list']   = 'stránky změněné ve jmenném prostoru:';
 $lang['mail_new_user']         = 'nový uživatel:';
-$lang['mail_upload']           = 'načtený dokument:';
+$lang['mail_upload']           = 'nahraný soubor:';
 $lang['changes_type']          = 'Prohlednou změny ';
 $lang['pages_changes']         = 'stránek';
 $lang['media_changes']         = 'souborů médií';
@@ -234,24 +274,21 @@ $lang['qb_sig']                = 'Vložit podpis';
 $lang['qb_smileys']            = 'Emotikony';
 $lang['qb_chars']              = 'Speciální znaky';
 $lang['upperns']               = 'skočit do nadřazeného jmenného prostoru';
-$lang['admin_register']        = 'Přidat nového uživatele';
 $lang['metaedit']              = 'Upravit Metadata';
 $lang['metasaveerr']           = 'Chyba při zápisu metadat';
 $lang['metasaveok']            = 'Metadata uložena';
-$lang['img_backto']            = 'Zpět na';
-$lang['img_title']             = 'Titulek';
-$lang['img_caption']           = 'Popis';
-$lang['img_date']              = 'Datum';
-$lang['img_fname']             = 'Jméno souboru';
-$lang['img_fsize']             = 'Velikost';
-$lang['img_artist']            = 'Autor fotografie';
-$lang['img_copyr']             = 'Copyright';
-$lang['img_format']            = 'Formát';
-$lang['img_camera']            = 'Typ fotoaparátu';
-$lang['img_keywords']          = 'Klíčová slova';
-$lang['img_width']             = 'Šířka';
-$lang['img_height']            = 'Výška';
-$lang['img_manager']           = 'Zobrazit ve správě médií';
+$lang['img_title']             = 'Titulek:';
+$lang['img_caption']           = 'Popis:';
+$lang['img_date']              = 'Datum:';
+$lang['img_fname']             = 'Jméno souboru:';
+$lang['img_fsize']             = 'Velikost:';
+$lang['img_artist']            = 'Autor fotografie:';
+$lang['img_copyr']             = 'Copyright:';
+$lang['img_format']            = 'Formát:';
+$lang['img_camera']            = 'Typ fotoaparátu:';
+$lang['img_keywords']          = 'Klíčová slova:';
+$lang['img_width']             = 'Šířka:';
+$lang['img_height']            = 'Výška:';
 $lang['subscr_subscribe_success'] = '%s byl přihlášen do seznamu odběratelů %s';
 $lang['subscr_subscribe_error'] = 'Došlo k chybě při přihlašování %s do seznamu odběratelů %s';
 $lang['subscr_subscribe_noaddress'] = 'K Vašemu loginu neexistuje žádná adresa, nemohl jste být přihlášen do seznamu odběratelů.';
@@ -260,17 +297,15 @@ $lang['subscr_unsubscribe_error'] = 'Došlo k chybě při odhlašování %s ze s
 $lang['subscr_already_subscribed'] = '%s již je přihlášen do seznamu odběratelů %s';
 $lang['subscr_not_subscribed'] = '%s není přihlášen do seznamu odběratelů %s';
 $lang['subscr_m_not_subscribed'] = 'V současné době neodebíráte změny na aktuální stránce nebo ve jmenném prostoru.';
-$lang['subscr_m_new_header']   = 'Přihlásit k odebírání změn emailem';
+$lang['subscr_m_new_header']   = 'Přihlásit k odebírání změn e-mailem';
 $lang['subscr_m_current_header'] = 'Aktuální odběratelé změn';
-$lang['subscr_m_unsubscribe']  = 'Odhlásit z odběru změn emailem';
-$lang['subscr_m_subscribe']    = 'Přihlásit se k odběru změn emailem';
+$lang['subscr_m_unsubscribe']  = 'Odhlásit z odběru změn e-mailem';
+$lang['subscr_m_subscribe']    = 'Přihlásit se k odběru změn e-mailem';
 $lang['subscr_m_receive']      = 'Přejete si dostávat';
-$lang['subscr_style_every']    = 'email pro každou změnu';
-$lang['subscr_style_digest']   = 'souhrnný email změn pro každou stránku (každé %.2f dny/dní)';
-$lang['subscr_style_list']     = 'seznam změněných stránek od posledního emailu (každé %.2f dny/dní)';
-$lang['authmodfailed']         = 'Autentizace uživatelů je špatně nastavena. Informujte prosím správce této wiki.';
+$lang['subscr_style_every']    = 'e-mail pro každou změnu';
+$lang['subscr_style_digest']   = 'souhrnný e-mail změn pro každou stránku (každé %.2f dny/dní)';
+$lang['subscr_style_list']     = 'seznam změněných stránek od posledního e-mailu (každé %.2f dny/dní)';
 $lang['authtempfail']          = 'Autentizace uživatelů je dočasně nedostupná. Pokud tento problém přetrvává, informujte prosím správce této wiki.';
-$lang['authpwdexpire']         = 'Platnost vašeho hesla vyprší za %d dní, měli byste ho změnit co nejdříve.';
 $lang['i_chooselang']          = 'Vyberte si jazyk';
 $lang['i_installer']           = 'Instalace DokuWiki';
 $lang['i_wikiname']            = 'Název wiki';
@@ -279,7 +314,11 @@ $lang['i_superuser']           = 'Správce';
 $lang['i_problems']            = 'Instalátor narazil na níže popsané problémy. Nelze pokračovat v instalaci, dokud je neopravíte.';
 $lang['i_modified']            = 'Instalátor bude z bezpečnostních důvodů pracovat pouze s čistou a ještě neupravenou instalací DokuWiki. Buď znovu rozbalte soubory z instalačního balíčku, nebo zkuste prostudovat <a href="http://dokuwiki.org/install">instrukce pro instalaci DokuWiki</a>.';
 $lang['i_funcna']              = 'PHP funkce <code>%s</code> není dostupná. Váš webhosting ji možná z nějakého důvodu vypnul.';
+$lang['i_disabled']            = 'Bylo zakázáno vaším poskytovatelem.';
+$lang['i_funcnmail']           = '<b>Poznámka:</b> Funkce mail() není v PHP dostupná. %s Pokud tento problém přetrvává, zkuste nainstalovat <a href="https://www.dokuwiki.org/plugin:smtp">smtp plugin</a>.';
 $lang['i_phpver']              = 'Verze vaší instalace PHP <code>%s</code> je nižší než požadovaná <code>%s</code>. Budete muset aktualizovat svou instalaci PHP.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload musí být vypnut v php.ini pro běh DokuWiki.';
+$lang['i_urandom']             = 'DokuWiki nemůže vytvořit kryptograficky bezpečná čísla pro cookies. Zkuste zkontrolovat nastavení open_basedir v php.ini, zda máte přistup k  <code>/dev/urandom </code>.';
 $lang['i_permfail']            = 'DokuWiki nemůže zapisovat do <code>%s</code>. Budete muset opravit práva k tomuto adresáři.';
 $lang['i_confexists']          = '<code>%s</code> již existuje';
 $lang['i_writeerr']            = 'Nelze vytvořit <code>%s</code>. Budete muset zkontrolovat práva k souborům či adresářům a vytvořit tento soubor ručně.';
@@ -291,8 +330,12 @@ $lang['i_policy']              = 'Úvodní politika ACL';
 $lang['i_pol0']                = 'Otevřená wiki (čtení, zápis a upload pro všechny)';
 $lang['i_pol1']                = 'Veřejná wiki (čtení pro všechny, zápis a upload pro registrované uživatele)';
 $lang['i_pol2']                = 'Uzavřená wiki (čtení, zápis a upload pouze pro registrované uživatele)';
+$lang['i_allowreg']            = 'Povol uživatelům registraci';
 $lang['i_retry']               = 'Zkusit znovu';
 $lang['i_license']             = 'Vyberte prosím licenci obsahu:';
+$lang['i_license_none']        = 'Nezobrazovat žádné licenční informace';
+$lang['i_pop_field']           = 'Prosím, pomozte nám vylepšit DokuWiki:';
+$lang['i_pop_label']           = 'Jednou měsíčně zaslat anonymní data o využívání DokuWiki jejím vývojářům';
 $lang['recent_global']         = 'Právě si prohlížíte změny ve jmenném prostoru <b>%s</b>. Také si můžete <a href="%s">zobrazit změny v celé wiki</a>.';
 $lang['years']                 = 'před %d roky';
 $lang['months']                = 'před %d měsíci';
@@ -325,3 +368,13 @@ $lang['media_perm_read']       = 'Bohužel, nemáte práva číst soubory.';
 $lang['media_perm_upload']     = 'Bohužel, nemáte práva nahrávat soubory.';
 $lang['media_update']          = 'Nahrát novou verzi';
 $lang['media_restore']         = 'Obnovit tuto verzi';
+$lang['media_acl_warning']     = 'Tento seznam nemusí být úplný z důvodu omezení práv ACL a skrytým stránkám.';
+$lang['email_fail']            = 'Funkce mail() v PHP chybí nebo je zakázána. Tato e-mailová zpráva nebyla odeslána:';
+$lang['currentns']             = 'Aktuální jmenný prostor';
+$lang['searchresult']          = 'Výsledek hledání';
+$lang['plainhtml']             = 'Čisté HTML';
+$lang['wikimarkup']            = 'Wiki jazyk';
+$lang['page_nonexist_rev']     = 'Stránka neexistovala na %s. Byla vytvořena dodatečne na <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Nelze rozebrat parametr "%s".';
+$lang['email_signature_text']  = 'Tento e-mail byl automaticky vygenerován systémem DokuWiki
+@DOKUWIKIURL@';
