@@ -1,14 +1,20 @@
 <?php
+
 /**
- * Greek language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
+ * @author Apostolos Tsompanopoulos <info@aptlogs.com>
+ * @author Katerina Katapodi <extragold1234@hotmail.com>
  * @author Thanos Massias <tm@thriasio.gr>
  * @author Αθανάσιος Νταής <homunculus@wana.gr>
  * @author Konstantinos Koryllos <koryllos@gmail.com>
  * @author George Petsagourakis <petsagouris@gmail.com>
  * @author Petros Vidalis <pvidalis@gmail.com>
- * @author Vasileios Karavasilis vasileioskaravasilis@gmail.com
+ * @author Vasileios Karavasilis <vasileioskaravasilis@gmail.com>
+ * @author Constantinos Xanthopoulos <conx@xanthopoulos.info>
+ * @author chris taklis <ctaklis@gmail.com>
+ * @author cross <cross1962@gmail.com>
+ * @author Zacharias Sdregas <zsdregas@sch.gr>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -40,7 +46,6 @@ $lang['btn_update']            = 'Ενημέρωση';
 $lang['btn_delete']            = 'Σβήσιμο';
 $lang['btn_back']              = 'Πίσω';
 $lang['btn_backlink']          = 'Σύνδεσμοι προς αυτή τη σελίδα';
-$lang['btn_backtomedia']       = 'Επιστροφή στην επιλογή αρχείων';
 $lang['btn_subscribe']         = 'Εγγραφή σε λήψη ενημερώσεων σελίδας';
 $lang['btn_profile']           = 'Επεξεργασία προφίλ';
 $lang['btn_reset']             = 'Ακύρωση';
@@ -52,7 +57,10 @@ $lang['btn_revert']            = 'Αποκατάσταση';
 $lang['btn_register']          = 'Εγγραφή';
 $lang['btn_apply']             = 'Εφαρμογή';
 $lang['btn_media']             = 'Διαχειριστής πολυμέσων';
-$lang['loggedinas']            = 'Συνδεδεμένος ως';
+$lang['btn_deleteuser']        = 'Αφαίρεσε τον λογαριασμό μου';
+$lang['btn_img_backto']        = 'Επιστροφή σε %s';
+$lang['btn_mediaManager']      = 'Εμφάνιση στον διαχειριστή πολυμέσων';
+$lang['loggedinas']            = 'Συνδεδεμένος ως:';
 $lang['user']                  = 'Όνομα χρήστη';
 $lang['pass']                  = 'Κωδικός';
 $lang['newpass']               = 'Νέος κωδικός';
@@ -63,40 +71,13 @@ $lang['fullname']              = 'Ονοματεπώνυμο';
 $lang['email']                 = 'e-mail';
 $lang['profile']               = 'Προφίλ χρήστη';
 $lang['badlogin']              = 'Συγνώμη, το όνομα χρήστη ή ο κωδικός ήταν λανθασμένο.';
+$lang['badpassconfirm']        = 'Ο κωδικός που εισάγατε είναι λανθασμένος';
 $lang['minoredit']             = 'Ασήμαντες αλλαγές';
 $lang['draftdate']             = 'Αυτόματη αποθήκευση πρόχειρης σελίδας στις';
 $lang['nosecedit']             = 'Η σελίδα τροποποιήθηκε στο μεταξύ και τα στοιχεία της ενότητας δεν ήταν συγχρονισμένα, οπότε φορτώθηκε η πλήρης σελίδα.  ';
-$lang['regmissing']            = 'Πρέπει να συμπληρώσετε όλα τα πεδία.';
-$lang['reguexists']            = 'Αυτός ο λογαριασμός υπάρχει ήδη.';
-$lang['regsuccess']            = 'Ο λογαριασμός δημιουργήθηκε και ο κωδικός εστάλει με e-mail.';
-$lang['regsuccess2']           = 'Ο λογαριασμός δημιουργήθηκε.';
-$lang['regmailfail']           = 'Φαίνεται να υπάρχει πρόβλημα με την αποστολή του κωδικού μέσω e-mail. Παρακαλούμε επικοινωνήστε μαζί μας!';
-$lang['regbadmail']            = 'Η διεύθυνση e-mail δεν είναι έγκυρη - εάν πιστεύετε ότι αυτό είναι λάθος, επικοινωνήστε μαζί μας';
-$lang['regbadpass']            = 'Οι δύο κωδικοί δεν είναι ίδιοι, προσπαθήστε ξανά.';
-$lang['regpwmail']             = 'Ο κωδικός σας';
-$lang['reghere']               = 'Δεν έχετε λογαριασμό ακόμη? Δημιουργήστε έναν';
-$lang['profna']                = 'Αυτό το wiki δεν υποστηρίζει την επεξεργασία προφίλ.';
-$lang['profnochange']          = 'Καμία αλλαγή.';
-$lang['profnoempty']           = 'Δεν επιτρέπεται κενό όνομα χρήστη η κενή διεύθυνση email.';
-$lang['profchanged']           = 'Το προφίλ χρήστη τροποποιήθηκε επιτυχώς.';
-$lang['pwdforget']             = 'Ξεχάσατε το κωδικό σας; Αποκτήστε νέο.';
-$lang['resendna']              = 'Αυτό το wiki δεν υποστηρίζει την εκ\' νέου αποστολή κωδικών.';
-$lang['resendpwd']             = 'Εισαγωγή νέου ωδικού για';
-$lang['resendpwdmissing']      = 'Πρέπει να συμπληρώσετε όλα τα πεδία.';
-$lang['resendpwdnouser']       = 'Αυτός ο χρήστης δεν υπάρχει στα αρχεία μας.';
-$lang['resendpwdbadauth']      = 'Αυτός ο κωδικός ενεργοποίησης δεν είναι έγκυρος.';
-$lang['resendpwdconfirm']      = 'Ο σύνδεσμος προς την σελίδα ενεργοποίησης εστάλει με e-mail.';
-$lang['resendpwdsuccess']      = 'Ο νέος σας κωδικός εστάλη με e-mail.';
-$lang['license']               = 'Εκτός εάν αναφέρεται διαφορετικά, το περιεχόμενο σε αυτο το wiki διέπεται από την ακόλουθη άδεια:';
-$lang['licenseok']             = 'Σημείωση: Τροποποιώντας αυτή την σελίδα αποδέχεστε την διάθεση του υλικού σας σύμφωνα με την ακόλουθη άδεια:';
-$lang['searchmedia']           = 'Αναζήτηση αρχείου:';
-$lang['searchmedia_in']        = 'Αναζήτηση σε %s';
-$lang['txt_upload']            = 'Επιλέξτε αρχείο για φόρτωση';
-$lang['txt_filename']          = 'Επιλέξτε νέο όνομα αρχείου (προαιρετικό)';
-$lang['txt_overwrt']           = 'Αντικατάσταση υπάρχοντος αρχείου';
-$lang['maxuploadsize']         = 'Μέγιστο μέγεθος αρχείου: %s.';
-$lang['lockedby']              = 'Προσωρινά κλειδωμένο από';
-$lang['lockexpire']            = 'Το κλείδωμα λήγει στις';
+$lang['searchcreatepage']      = 'Αν δεν βρήκατε αυτό που ψάχνατε, μπορείτε να δημιουργήσετε και να εκδώσετε την σελίδα %s, που ονομάστηκε μετά την αναζήτηση.';
+$lang['search_fullresults']    = 'Ολοκληρωμένα αποτελέσματα';
+$lang['js']['search_toggle_tools'] = 'Χρησιμοποιήστε τα Εργαλεία Αναζήτησης';
 $lang['js']['willexpire']      = 'Το κλείδωμά σας για την επεξεργασία αυτής της σελίδας θα λήξει σε ένα λεπτό.\n Για να το ανανεώσετε χρησιμοποιήστε την Προεπισκόπηση.';
 $lang['js']['notsavedyet']     = 'Οι μη αποθηκευμένες αλλαγές θα χαθούν.
 Θέλετε να συνεχίσετε;';
@@ -140,14 +121,64 @@ $lang['js']['media_done_btn']  = 'Ολοκλήρωση';
 $lang['js']['media_drop']      = 'Ρίξτε αρχεία εδώ για να τα φορτώσετε';
 $lang['js']['media_cancel']    = 'αφαίρεση';
 $lang['js']['media_overwrt']   = 'Αντικατάσταση υπάρχοντων αρχείων';
+$lang['search_exact_match']    = 'Απόλυτο ταίριασμα';
+$lang['search_starts_with']    = 'Αρχίζει με';
+$lang['search_ends_with']      = 'Τελειώνει με';
+$lang['search_contains']       = 'Περιέχει';
+$lang['search_custom_match']   = 'Προσωποποίηση';
+$lang['search_any_ns']         = 'Οιοδήποτε κενό με όνομα';
+$lang['search_any_time']       = 'Οιαδήποτε στιγμή';
+$lang['search_past_7_days']    = 'Την περασμένη εβδομάδα';
+$lang['search_past_month']     = 'Τον περασμένο μήνα';
+$lang['search_past_year']      = 'Τον περασμένο χρόνο';
+$lang['search_sort_by_hits']   = 'Επιλογή με βάση τα κλικ';
+$lang['search_sort_by_mtime']  = 'Επιλογή σύμφωνα με την τελευταία τροποποίηση';
+$lang['regmissing']            = 'Πρέπει να συμπληρώσετε όλα τα πεδία.';
+$lang['reguexists']            = 'Αυτός ο λογαριασμός υπάρχει ήδη.';
+$lang['regsuccess']            = 'Ο λογαριασμός δημιουργήθηκε και ο κωδικός εστάλει με e-mail.';
+$lang['regsuccess2']           = 'Ο λογαριασμός δημιουργήθηκε.';
+$lang['regfail']               = 'Δεν έγινε η δημιουργία χρήστη.';
+$lang['regmailfail']           = 'Φαίνεται να υπάρχει πρόβλημα με την αποστολή του κωδικού μέσω e-mail. Παρακαλούμε επικοινωνήστε μαζί μας!';
+$lang['regbadmail']            = 'Η διεύθυνση e-mail δεν είναι έγκυρη - εάν πιστεύετε ότι αυτό είναι λάθος, επικοινωνήστε μαζί μας';
+$lang['regbadpass']            = 'Οι δύο κωδικοί δεν είναι ίδιοι, προσπαθήστε ξανά.';
+$lang['regpwmail']             = 'Ο κωδικός σας';
+$lang['reghere']               = 'Δεν έχετε λογαριασμό ακόμη; Δημιουργήστε έναν';
+$lang['profna']                = 'Αυτό το wiki δεν υποστηρίζει την επεξεργασία προφίλ.';
+$lang['profnochange']          = 'Καμία αλλαγή.';
+$lang['profnoempty']           = 'Δεν επιτρέπεται κενό όνομα χρήστη η κενή διεύθυνση email.';
+$lang['profchanged']           = 'Το προφίλ χρήστη τροποποιήθηκε επιτυχώς.';
+$lang['profnodelete']          = 'Το wiki δεν υποστηρίζει την διαγραφή χρηστών';
+$lang['profdeleteuser']        = 'Διαγραφή λογαριασμού';
+$lang['profdeleted']           = 'Ο λογαριασμός διαγράφηκε από αυτό το wiki';
+$lang['profconfdelete']        = 'Επιθυμώ να διαγράψω τον λογαριασμό μου από αυτό το wiki. <br/> Αυτή η επιλογή δεν μπορεί να αναιρεθεί.';
+$lang['profconfdeletemissing'] = 'Το κουμπί επιβεβαίωσης δεν πατήθηκε';
+$lang['proffail']              = 'Δεν ενημερώθηκε το προφίλ του χρήστη.';
+$lang['pwdforget']             = 'Ξεχάσατε το κωδικό σας; Αποκτήστε νέο.';
+$lang['resendna']              = 'Αυτό το wiki δεν υποστηρίζει την εκ\' νέου αποστολή κωδικών.';
+$lang['resendpwd']             = 'Εισαγωγή νέου ωδικού για';
+$lang['resendpwdmissing']      = 'Πρέπει να συμπληρώσετε όλα τα πεδία.';
+$lang['resendpwdnouser']       = 'Αυτός ο χρήστης δεν υπάρχει στα αρχεία μας.';
+$lang['resendpwdbadauth']      = 'Αυτός ο κωδικός ενεργοποίησης δεν είναι έγκυρος.';
+$lang['resendpwdconfirm']      = 'Ο σύνδεσμος προς την σελίδα ενεργοποίησης εστάλει με e-mail.';
+$lang['resendpwdsuccess']      = 'Ο νέος σας κωδικός εστάλη με e-mail.';
+$lang['license']               = 'Εκτός εάν αναφέρεται διαφορετικά, το περιεχόμενο σε αυτο το wiki διέπεται από την ακόλουθη άδεια:';
+$lang['licenseok']             = 'Σημείωση: Τροποποιώντας αυτή την σελίδα αποδέχεστε την διάθεση του υλικού σας σύμφωνα με την ακόλουθη άδεια:';
+$lang['searchmedia']           = 'Αναζήτηση αρχείου:';
+$lang['searchmedia_in']        = 'Αναζήτηση σε %s';
+$lang['txt_upload']            = 'Επιλέξτε αρχείο για φόρτωση:';
+$lang['txt_filename']          = 'Επιλέξτε νέο όνομα αρχείου (προαιρετικό):';
+$lang['txt_overwrt']           = 'Αντικατάσταση υπάρχοντος αρχείου';
+$lang['maxuploadsize']         = 'Μέγιστο μέγεθος αρχείου: %s.';
+$lang['lockedby']              = 'Προσωρινά κλειδωμένο από:';
+$lang['lockexpire']            = 'Το κλείδωμα λήγει στις:';
 $lang['rssfailed']             = 'Παρουσιάστηκε κάποιο σφάλμα κατά την ανάγνωση αυτού του feed: ';
 $lang['nothingfound']          = 'Δεν βρέθηκαν σχετικά αποτελέσματα.';
 $lang['mediaselect']           = 'Επιλογή Αρχείων';
-$lang['fileupload']            = 'Φόρτωση αρχείου';
 $lang['uploadsucc']            = 'Επιτυχής φόρτωση';
 $lang['uploadfail']            = 'Η μεταφόρτωση απέτυχε. Πιθανόν αυτό να οφείλεται στις ρυθμίσεις πρόσβασης του αρχείου.';
 $lang['uploadwrong']           = 'Η μεταφόρτωση δεν έγινε δεκτή. Δεν επιτρέπονται αρχεία αυτού του τύπου!';
 $lang['uploadexist']           = 'Το αρχείο ήδη υπάρχει. Δεν έγινε καμία αλλαγή.';
+$lang['uploadbadcontent']      = 'Το περιεχόμενο που φορτώθηκε δεν ταίριαζε το %s της προέκτασης του φακέλλου.';
 $lang['uploadspam']            = 'Η μεταφόρτωση ακυρώθηκε από το φίλτρο spam.';
 $lang['uploadxss']             = 'Η μεταφόρτωση ακυρώθηκε λόγω πιθανού επικίνδυνου περιεχομένου.';
 $lang['uploadsize']            = 'Το αρχείο ήταν πολύ μεγάλο. (μέγιστο %s)';
@@ -176,10 +207,15 @@ $lang['difflink']              = 'Σύνδεσμος σε αυτή την προ
 $lang['diff_type']             = 'Προβολή διαφορών:';
 $lang['diff_inline']           = 'Σε σειρά';
 $lang['diff_side']             = 'Δίπλα-δίπλα';
+$lang['diffprevrev']           = 'Προηγούμενη αναθεώρηση';
+$lang['diffnextrev']           = 'Επόμενη αναθεώρηση';
+$lang['difflastrev']           = 'Τελευταία αναθεώρηση';
+$lang['diffbothprevrev']       = 'Προηγούμενος έλεγχος και από τις δύο πλευρές';
+$lang['diffbothnextrev']       = 'Επόμενος έλεγχος και από τις δύο πλευρές';
 $lang['line']                  = 'Γραμμή';
-$lang['breadcrumb']            = 'Ιστορικό';
-$lang['youarehere']            = 'Είστε εδώ';
-$lang['lastmod']               = 'Τελευταία τροποποίηση';
+$lang['breadcrumb']            = 'Ιστορικό:';
+$lang['youarehere']            = 'Είστε εδώ:';
+$lang['lastmod']               = 'Τελευταία τροποποίηση:';
 $lang['by']                    = 'από';
 $lang['deleted']               = 'διαγράφηκε';
 $lang['created']               = 'δημιουργήθηκε';
@@ -228,24 +264,21 @@ $lang['qb_sig']                = 'Προσθήκη Υπογραφής';
 $lang['qb_smileys']            = 'Smileys';
 $lang['qb_chars']              = 'Ειδικοί Χαρακτήρες';
 $lang['upperns']               = 'πήγαινε στον μητρικό φάκελο';
-$lang['admin_register']        = 'Προσθήκη νέου χρήστη';
 $lang['metaedit']              = 'Τροποποίηση metadata';
 $lang['metasaveerr']           = 'Η αποθήκευση των metadata απέτυχε';
 $lang['metasaveok']            = 'Επιτυχής αποθήκευση metadata';
-$lang['img_backto']            = 'Επιστροφή σε';
-$lang['img_title']             = 'Τίτλος';
-$lang['img_caption']           = 'Λεζάντα';
-$lang['img_date']              = 'Ημερομηνία';
-$lang['img_fname']             = 'Όνομα αρχείου';
-$lang['img_fsize']             = 'Μέγεθος';
-$lang['img_artist']            = 'Καλλιτέχνης';
-$lang['img_copyr']             = 'Copyright';
-$lang['img_format']            = 'Format';
-$lang['img_camera']            = 'Camera';
-$lang['img_keywords']          = 'Λέξεις-κλειδιά';
-$lang['img_width']             = 'Πλάτος';
-$lang['img_height']            = 'Ύψος';
-$lang['img_manager']           = 'Εμφάνιση στον διαχειριστή πολυμέσων';
+$lang['img_title']             = 'Τίτλος:';
+$lang['img_caption']           = 'Λεζάντα:';
+$lang['img_date']              = 'Ημερομηνία:';
+$lang['img_fname']             = 'Όνομα αρχείου:';
+$lang['img_fsize']             = 'Μέγεθος:';
+$lang['img_artist']            = 'Καλλιτέχνης:';
+$lang['img_copyr']             = 'Copyright:';
+$lang['img_format']            = 'Format:';
+$lang['img_camera']            = 'Camera:';
+$lang['img_keywords']          = 'Λέξεις-κλειδιά:';
+$lang['img_width']             = 'Πλάτος:';
+$lang['img_height']            = 'Ύψος:';
 $lang['subscr_subscribe_success'] = 'Ο/η %s προστέθηκε στην λίστα ειδοποιήσεων για το %s';
 $lang['subscr_subscribe_error'] = 'Σφάλμα κατά την προσθήκη του/της %s στην λίστα ειδοποιήσεων για το %s';
 $lang['subscr_subscribe_noaddress'] = 'Δεν υπάρχει διεύθυνση ταχυδρομείου συσχετισμένη με το όνομα χρήστη σας. Κατά συνέπεια δεν μπορείτε να προστεθείτε στην λίστα ειδοποιήσεων';
@@ -262,9 +295,7 @@ $lang['subscr_m_receive']      = 'Λήψη';
 $lang['subscr_style_every']    = 'email σε κάθε αλλαγή';
 $lang['subscr_style_digest']   = 'συνοπτικό email αλλαγών της σελίδας (κάθε %.2f μέρες)';
 $lang['subscr_style_list']     = 'λίστα σελίδων με αλλαγές μετά από το τελευταίο email (κάθε %.2f μέρες)';
-$lang['authmodfailed']         = 'Κακή ρύθμιση λίστας χρηστών. Παρακαλούμε ενημερώστε τον διαχειριστή του wiki.';
 $lang['authtempfail']          = 'Η συνδεση χρηστών είναι απενεργοποιημένη αυτή την στιγμή. Αν αυτό διαρκέσει για πολύ, παρακαλούμε ενημερώστε τον διαχειριστή του wiki.';
-$lang['authpwdexpire']         = 'Ο κωδικός πρόσβασης θα λήξει σε %s ημέρες. Προτείνουμε να τον αλλάξετε σύντομα.';
 $lang['i_chooselang']          = 'Επιλογή γλώσσας';
 $lang['i_installer']           = 'Οδηγός εγκατάστασης DokuWiki';
 $lang['i_wikiname']            = 'Ονομασία wiki';
@@ -275,19 +306,24 @@ $lang['i_modified']            = 'Για λόγους ασφαλείας, ο ο
 Πρέπει είτε να κάνετε νέα εγκατάσταση, χρησιμοποιώντας το αρχικό πακέτο εγκατάστασης, ή να συμβουλευτείτε τις <a href="http://dokuwiki.org/el:install">οδηγίες εγκατάστασης της εφαρμογής</a>.';
 $lang['i_funcna']              = 'Η λειτουργία <code>%s</code> της PHP δεν είναι διαθέσιμη. Πιθανόν να είναι απενεργοποιημένη στις ρυθμίσεις έναρξης της PHP';
 $lang['i_phpver']              = 'Η έκδοση <code>%s</code> της PHP που έχετε είναι παλαιότερη της απαιτούμενης <code>%s</code>. Πρέπει να αναβαθμίσετε την PHP.';
+$lang['i_mbfuncoverload']      = 'Για να εκτελεστεί το Dokuwiki πρέπει να απενεργοποιήσετε τη ρύθμιση mbstring.func_overload στο αρχείο php.ini';
 $lang['i_permfail']            = 'Ο φάκελος <code>%s</code> δεν είναι εγγράψιμος από την εφαρμογή DokuWiki. Πρέπει να διορθώσετε τα δικαιώματα πρόσβασης αυτού του φακέλου!';
 $lang['i_confexists']          = '<code>%s</code> υπάρχει ήδη';
 $lang['i_writeerr']            = 'Δεν είναι δυνατή η δημιουργία του <code>%s</code>. Πρέπει να διορθώσετε τα δικαιώματα πρόσβασης αυτού του φακέλου/αρχείου και να δημιουργήσετε το αρχείο χειροκίνητα!';
 $lang['i_badhash']             = 'Μη αναγνωρίσιμο ή τροποποιημένο αρχείο dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - λάθος ή ανύπαρκτη τιμή';
-$lang['i_success']             = 'Η εγκατάσταση ολοκληρώθηκε επιτυχώς. Μπορείτε πλέον να διαγράψετε το αρχείο install.php. Συνεχίστε στο <a href="doku.php">νέο σας DokuWiki</a>.';
-$lang['i_failure']             = 'Εμφανίστηκαν κάποια προβλήματα στη διαδικασία ανανέωσης των αρχείων ρυθμίσεων. Πιθανόν να χρειάζεται να τα τροποποιήσετε χειροκίνητα ώστε να μπορείτε να χρησιμοποιήσετε το <a href="doku.php">νέο σας DokuWiki</a>.';
+$lang['i_success']             = 'Η εγκατάσταση ολοκληρώθηκε επιτυχώς. Μπορείτε πλέον να διαγράψετε το αρχείο install.php. Συνεχίστε στο <a href="doku.php?id=wiki:welcome">νέο σας DokuWiki</a>.';
+$lang['i_failure']             = 'Εμφανίστηκαν κάποια προβλήματα στη διαδικασία ανανέωσης των αρχείων ρυθμίσεων. Πιθανόν να χρειάζεται να τα τροποποιήσετε χειροκίνητα ώστε να μπορείτε να χρησιμοποιήσετε το <a href="doku.php?id=wiki:welcome">νέο σας DokuWiki</a>.';
 $lang['i_policy']              = 'Αρχική πολιτική Λίστας Δικαιωμάτων Πρόσβασης - ACL';
 $lang['i_pol0']                = 'Ανοιχτό Wiki (όλοι μπορούν να διαβάσουν ή να δημιουργήσουν/τροποποιήσουν σελίδες και να μεταφορτώσουν αρχεία)';
 $lang['i_pol1']                = 'Δημόσιο Wiki (όλοι μπορούν να διαβάσουν σελίδες αλλά μόνο οι εγγεγραμμένοι χρήστες μπορούν να δημιουργήσουν/τροποποιήσουν σελίδες και να μεταφορτώσουν αρχεία)';
 $lang['i_pol2']                = 'Κλειστό Wiki (μόνο οι εγγεγραμμένοι χρήστες μπορούν να διαβάσουν ή να δημιουργήσουν/τροποποιήσουν σελίδες και να μεταφορτώσουν αρχεία)';
+$lang['i_allowreg']            = 'Οι χρήστες επιτρέπεται να εγγραφούν μόνοι τους';
 $lang['i_retry']               = 'Νέα προσπάθεια';
 $lang['i_license']             = 'Παρακαλώ επιλέξτε την άδεια που θα χρησιμοποιήσετε για την διάθεση του περιεχομένου σας:';
+$lang['i_license_none']        = 'Μην προβάλλετε καθόλου πληροφορίες σχετικά με την άδεια';
+$lang['i_pop_field']           = 'Παρακαλώ, βοηθήστε μας να βελτιώσουμε το Dokuwiki';
+$lang['i_pop_label']           = 'Μια φορά τον μήνα, στέλνετε δεδομένα προς χρήση στους δημιουργούς του  Dokuwiki';
 $lang['recent_global']         = 'Βλέπετε τις αλλαγές εντός του φακέλου <b>%s</b>. Μπορείτε επίσης να <a href="%s">δείτε τις πρόσφατες αλλαγές σε όλο το wiki</a>.';
 $lang['years']                 = 'πριν %d χρόνια';
 $lang['months']                = 'πριν %d μήνες';
@@ -314,8 +350,18 @@ $lang['media_search']          = 'Αναζήτηση στο <strong>%s</strong>
 $lang['media_view']            = '%s';
 $lang['media_viewold']         = '%s στα %s';
 $lang['media_edit']            = 'Επεξεργασία %s';
+$lang['media_history']         = 'Ιστορικό των %s';
 $lang['media_meta_edited']     = 'τα μεταδεδομένα επεξεργάστηκαν';
 $lang['media_perm_read']       = 'Συγνώμη, δεν έχετε επαρκή διακαιώματα για να διαβάσετε αυτά τα αρχεία.';
 $lang['media_perm_upload']     = 'Συγνώμη, δεν έχετε επαρκή διακαιώματα για να φορτώσετε αυτά τα αρχεία.';
 $lang['media_update']          = 'Φόρτωση νέας έκδοσης';
 $lang['media_restore']         = 'Επαναφορά αυτή της έκδοσης';
+$lang['media_acl_warning']     = 'Αυτή η λίστα πιθανόν να μην είναι πλήρης λόγω του ACL, περιορισμούς και κρυμμένες σελίδες.';
+$lang['currentns']             = 'Χώρος για όνομα';
+$lang['searchresult']          = 'Αποτέλεσμα έρευνας';
+$lang['plainhtml']             = 'Απλό HTML';
+$lang['wikimarkup']            = 'Wiki Markup';
+$lang['page_nonexist_rev']     = 'Δεν υπήρξε σελίδα στο %s. Δημιουργήθηκε στη συνέχεια στο <a href=\'\'%s\'\'>%s,</a>.';
+$lang['unable_to_parse_date']  = 'Δεν μπόρεσε να περάσει στην παράμετρο \'\'%s\'\'.';
+$lang['email_signature_text']  = 'Αυτό το e-mail δημιουργήθηκε αυτόματα από την εφαρμογή DokuWiki στην διεύθυνση
+@DOKUWIKIURL@';
