@@ -1,19 +1,26 @@
 <?php
+
 /**
- * Slovak language file
+ * slovak language file
  *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
+ * auth.class language support 
+ * installer strings 
+ *
+ * @author Peter Mydliar <peto.mydliar@gmail.com>
+ * @author Martin Michalek <michalek.dev@gmail.com>
  * @author Ondrej Vegh <ov@vsieti.sk> with help of the scholars from Zdruzena stredna skola polygraficka in Bratislava
  * @author Michal Mesko <michal.mesko@gmail.com>
- * @author exusik@gmail.com
- * @author Martin Michalek <michalek.dev@gmail.com>
+ * @author exusik <exusik@gmail.com>
+ * @author Tibor Repček <tiborepcek@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
-$lang['doublequoteopening']    = '„';
-$lang['doublequoteclosing']    = '“';
-$lang['singlequoteopening']    = '‚';
-$lang['singlequoteclosing']    = '‘';
+$lang['doublequoteopening']    = '“';
+$lang['doublequoteclosing']    = '”';
+$lang['singlequoteopening']    = '‘';
+$lang['singlequoteclosing']    = '’';
 $lang['apostrophe']            = '’';
 $lang['btn_edit']              = 'Upraviť stránku';
 $lang['btn_source']            = 'Zobraziť zdroj stránky';
@@ -38,7 +45,6 @@ $lang['btn_update']            = 'Aktualizovať';
 $lang['btn_delete']            = 'Zmazať';
 $lang['btn_back']              = 'Späť';
 $lang['btn_backlink']          = 'Spätné odkazy';
-$lang['btn_backtomedia']       = 'Späť na výber súboru';
 $lang['btn_subscribe']         = 'Sledovať zmeny';
 $lang['btn_profile']           = 'Aktualizovať profil';
 $lang['btn_reset']             = 'Zrušiť';
@@ -50,8 +56,11 @@ $lang['btn_revert']            = 'Obnoviť';
 $lang['btn_register']          = 'Registrovať';
 $lang['btn_apply']             = 'Použiť';
 $lang['btn_media']             = 'Správa médií';
-$lang['loggedinas']            = 'Prihlásený(á) ako';
-$lang['user']                  = 'Užívateľské meno';
+$lang['btn_deleteuser']        = 'Zrušiť môj účet';
+$lang['btn_img_backto']        = 'Späť na %s';
+$lang['btn_mediaManager']      = 'Prezrieť v správcovi médií';
+$lang['loggedinas']            = 'Prihlásený(á) ako:';
+$lang['user']                  = 'Používateľské meno';
 $lang['pass']                  = 'Heslo';
 $lang['newpass']               = 'Nové heslo';
 $lang['oldpass']               = 'Potvrď aktuálne heslo';
@@ -59,42 +68,15 @@ $lang['passchk']               = 'Ešte raz znovu';
 $lang['remember']              = 'Zapamätaj si ma';
 $lang['fullname']              = 'Celé meno';
 $lang['email']                 = 'E-Mail';
-$lang['profile']               = 'Užívateľský profil';
-$lang['badlogin']              = 'Zadané užívateľské meno a heslo nie je správne.';
+$lang['profile']               = 'Používateľský profil';
+$lang['badlogin']              = 'Zadané používateľské meno a heslo nie je správne.';
+$lang['badpassconfirm']        = 'Ľutujem, heslo bolo nesprávne.';
 $lang['minoredit']             = 'Menšie zmeny';
 $lang['draftdate']             = 'Koncept automaticky uložený';
 $lang['nosecedit']             = 'Stránka bola medzičasom zmenená, informácie o sekcii sú zastaralé a z tohto dôvodu bola nahraná celá stránka.';
-$lang['regmissing']            = 'Musíte vyplniť všetky údaje.';
-$lang['reguexists']            = 'Užívateľ s rovnakým menom je už zaregistrovaný.';
-$lang['regsuccess']            = 'Užívateľský účet bol vytvorený a heslo zaslané emailom.';
-$lang['regsuccess2']           = 'Užívateľský účet bol vytvorený.';
-$lang['regmailfail']           = 'Zdá sa, že nastala chyba pri posielaní mailu s heslom. Skúste kontaktovať správcu.';
-$lang['regbadmail']            = 'Zadaná emailová adresa nie je platná. Pokiaľ si myslíte, že to je zle, skúste kontaktovať správcu.';
-$lang['regbadpass']            = 'Zadané heslá nie sú rovnaké, zadajte ich prosím znovu.';
-$lang['regpwmail']             = 'Vaše heslo do systému DokuWiki';
-$lang['reghere']               = 'Nemáte užívateľský účet? Vytvorte si ho';
-$lang['profna']                = 'Táto wiki nepodporuje zmenu profilu';
-$lang['profnochange']          = 'Žiadne zmeny, nie je čo robiť.';
-$lang['profnoempty']           = 'Prázdne meno alebo mailová adresa nie sú povolené.';
-$lang['profchanged']           = 'Užívateľský účet úspešne zmenený.';
-$lang['pwdforget']             = 'Zabudli ste heslo? Získajte nové!';
-$lang['resendna']              = 'Táto wiki nepodporuje opätovné zasielanie hesla.';
-$lang['resendpwd']             = 'Nastaviť nové heslo pre';
-$lang['resendpwdmissing']      = 'Prepáčte, musíte vyplniť všetky polia.';
-$lang['resendpwdnouser']       = 'Prepáčte, nemôžeme nájsť zadaného užívateľa v databáze.';
-$lang['resendpwdbadauth']      = 'Prepáčte, tento autorizačný kód nie je platný. Uistite sa, či ste použili celý autorizačný odkaz.';
-$lang['resendpwdconfirm']      = 'Autorizačný odkaz bol zaslaný na e-mail.';
-$lang['resendpwdsuccess']      = 'Vaše nové heslo bolo zaslané na e-mail.';
-$lang['license']               = 'Ak nie je uvedené inak, obsah tejto wiki je uverejnený pod nasledujúcou licenciou:';
-$lang['licenseok']             = 'Poznámka: Zmenou tejto stránky súhlasíte s uverejnením obsahu pod nasledujúcou licenciou:';
-$lang['searchmedia']           = 'Hľadať meno súboru:';
-$lang['searchmedia_in']        = 'Hľadať v %s';
-$lang['txt_upload']            = 'Vyberte súbor ako prílohu';
-$lang['txt_filename']          = 'Uložiť ako (voliteľné)';
-$lang['txt_overwrt']           = 'Prepísať existujúci súbor';
-$lang['maxuploadsize']         = 'Obmedzenie max. %s na súbor.';
-$lang['lockedby']              = 'Práve zamknuté:';
-$lang['lockexpire']            = 'Zámok stratí platnosť:';
+$lang['searchcreatepage']      = 'Ak ste nenašli, čo ste hľadali, môžete vytvoriť alebo upraviť stránku %s, ktorá bola nazvaná podľa vášho dopytu.';
+$lang['search_fullresults']    = 'Fulltextové výsledky';
+$lang['js']['search_toggle_tools'] = 'Zobraziť/Skryť vyhľadávacie nástroje';
 $lang['js']['willexpire']      = 'Váš zámok pre editáciu za chvíľu stratí platnosť.\nAby ste predišli konfliktom, stlačte tlačítko Náhľad a zámok sa predĺži.';
 $lang['js']['notsavedyet']     = 'Neuložené zmeny budú stratené.
 Chcete naozaj pokračovať?';
@@ -122,8 +104,7 @@ $lang['js']['medialeft']       = 'Zarovnať obrázok vľavo.';
 $lang['js']['mediaright']      = 'Zarovnať obrázok vpravo.';
 $lang['js']['mediacenter']     = 'Zarovnať obrázok na stred.';
 $lang['js']['medianoalign']    = 'Nepoužívať zarovnanie.';
-$lang['js']['nosmblinks']      = 'Odkazovanie na zdieľané prostriedky Windows funguje len v Internet Exploreri.
-Aj napriek tomu tento odkaz môžete skopírovať a vložiť inde.';
+$lang['js']['nosmblinks']      = 'Odkazovanie na zdieľané prostriedky Windows funguje len v Internet Exploreri.\nAj napriek tomu tento odkaz môžete skopírovať a vložiť inde.';
 $lang['js']['linkwiz']         = 'Sprievodca odkazmi';
 $lang['js']['linkto']          = 'Odkaz na:';
 $lang['js']['del_confirm']     = 'Zmazať túto položku?';
@@ -138,10 +119,59 @@ $lang['js']['media_done_btn']  = 'Hotovo';
 $lang['js']['media_drop']      = 'Pridajte súbory potiahnutím myšou';
 $lang['js']['media_cancel']    = 'odstrániť';
 $lang['js']['media_overwrt']   = 'Prepísať existujúce súbory';
+$lang['search_exact_match']    = 'Presná zhoda';
+$lang['search_starts_with']    = 'Začín na';
+$lang['search_ends_with']      = 'Končí na';
+$lang['search_contains']       = 'Obsahuje';
+$lang['search_custom_match']   = 'Vlastný';
+$lang['search_any_ns']         = 'Akýkoľvek menný priestor';
+$lang['search_any_time']       = 'Kedykoľvek';
+$lang['search_past_7_days']    = 'Posledný týždeň';
+$lang['search_past_month']     = 'Posledný mesiac';
+$lang['search_past_year']      = 'Posledný  rok';
+$lang['search_sort_by_hits']   = 'Zoradiť podľa počtu návštev';
+$lang['search_sort_by_mtime']  = 'Zoradiť podľa posledných úprav';
+$lang['regmissing']            = 'Musíte vyplniť všetky údaje.';
+$lang['reguexists']            = 'Používateľ s rovnakým menom je už zaregistrovaný.';
+$lang['regsuccess']            = 'Používateľský účet bol vytvorený a heslo zaslané emailom.';
+$lang['regsuccess2']           = 'Používateľský účet bol vytvorený.';
+$lang['regfail']               = 'Používateľský účet nemôže byť vytvorený.';
+$lang['regmailfail']           = 'Zdá sa, že nastala chyba pri posielaní mailu s heslom. Skúste kontaktovať správcu.';
+$lang['regbadmail']            = 'Zadaná emailová adresa nie je platná. Pokiaľ si myslíte, že to je zle, skúste kontaktovať správcu.';
+$lang['regbadpass']            = 'Zadané heslá nie sú rovnaké, zadajte ich prosím znovu.';
+$lang['regpwmail']             = 'Vaše heslo do systému DokuWiki';
+$lang['reghere']               = 'Nemáte používateľský účet? Vytvorte si ho';
+$lang['profna']                = 'Táto wiki nepodporuje zmenu profilu';
+$lang['profnochange']          = 'Žiadne zmeny, nie je čo robiť.';
+$lang['profnoempty']           = 'Prázdne meno alebo mailová adresa nie sú povolené.';
+$lang['profchanged']           = 'Profil požívateľa bol úspešne zmenený.';
+$lang['profnodelete']          = 'Táto wiki neumožňuje zrušenie používateľov.';
+$lang['profdeleteuser']        = 'Zrušiť účet';
+$lang['profdeleted']           = 'Váš účet bol zrušený v tejto wiki.';
+$lang['profconfdelete']        = 'Chcem odstrániť môj účet z tejto wiki. <br/> Táto operácia je nevratná.';
+$lang['profconfdeletemissing'] = 'Nebolo zavolené potvrdzovacie políčko';
+$lang['proffail']              = 'Profil používateľa nebol aktualizovaný.';
+$lang['pwdforget']             = 'Zabudli ste heslo? Získajte nové!';
+$lang['resendna']              = 'Táto wiki nepodporuje opätovné zasielanie hesla.';
+$lang['resendpwd']             = 'Nastaviť nové heslo pre';
+$lang['resendpwdmissing']      = 'Prepáčte, musíte vyplniť všetky polia.';
+$lang['resendpwdnouser']       = 'Prepáčte, nemôžeme nájsť zadaného používateľa v databáze.';
+$lang['resendpwdbadauth']      = 'Prepáčte, tento autorizačný kód nie je platný. Uistite sa, či ste použili celý autorizačný odkaz.';
+$lang['resendpwdconfirm']      = 'Autorizačný odkaz bol zaslaný na e-mail.';
+$lang['resendpwdsuccess']      = 'Vaše nové heslo bolo zaslané na e-mail.';
+$lang['license']               = 'Ak nie je uvedené inak, obsah tejto wiki je uverejnený pod nasledujúcou licenciou:';
+$lang['licenseok']             = 'Poznámka: Zmenou tejto stránky súhlasíte s uverejnením obsahu pod nasledujúcou licenciou:';
+$lang['searchmedia']           = 'Hľadať meno súboru:';
+$lang['searchmedia_in']        = 'Hľadať v %s';
+$lang['txt_upload']            = 'Vyberte súbor ako prílohu:';
+$lang['txt_filename']          = 'Uložiť ako (voliteľné):';
+$lang['txt_overwrt']           = 'Prepísať existujúci súbor';
+$lang['maxuploadsize']         = 'Obmedzenie max. %s na súbor.';
+$lang['lockedby']              = 'Práve zamknuté:';
+$lang['lockexpire']            = 'Zámok stratí platnosť:';
 $lang['rssfailed']             = 'Nastala chyba pri vytváraní tohto RSS: ';
 $lang['nothingfound']          = 'Nič nenájdené.';
 $lang['mediaselect']           = 'Výber súboru';
-$lang['fileupload']            = 'Nahrávanie súboru';
 $lang['uploadsucc']            = 'Prenos prebehol v poriadku';
 $lang['uploadfail']            = 'Chyba pri nahrávaní. Možno kvôli zle nastaveným právam?';
 $lang['uploadwrong']           = 'Prenos súboru s takouto príponou nie je dovolený.';
@@ -175,10 +205,15 @@ $lang['difflink']              = 'Odkaz na tento prehľad zmien';
 $lang['diff_type']             = 'Prehľad zmien:';
 $lang['diff_inline']           = 'Vnorený';
 $lang['diff_side']             = 'Vedľa seba';
+$lang['diffprevrev']           = 'Predchádzajúca revízia';
+$lang['diffnextrev']           = 'Nasledujúca revízia';
+$lang['difflastrev']           = 'Posledná revízia';
+$lang['diffbothprevrev']       = 'Obojstranná predošlá revízia';
+$lang['diffbothnextrev']       = 'Obojstranná nasledujúca revízia';
 $lang['line']                  = 'Riadok';
-$lang['breadcrumb']            = 'História';
-$lang['youarehere']            = 'Nachádzate sa';
-$lang['lastmod']               = 'Posledná úprava';
+$lang['breadcrumb']            = 'Cesta:';
+$lang['youarehere']            = 'Nachádzate sa:';
+$lang['lastmod']               = 'Posledná úprava:';
 $lang['by']                    = 'od';
 $lang['deleted']               = 'odstránené';
 $lang['created']               = 'vytvorené';
@@ -196,7 +231,7 @@ $lang['sidebar']               = 'Bočný panel';
 $lang['mail_newpage']          = 'stránka pridaná:';
 $lang['mail_changed']          = 'stránka zmenená:';
 $lang['mail_subscribe_list']   = 'stránky zmenené v mennom priestore:';
-$lang['mail_new_user']         = 'nový užívateľ:';
+$lang['mail_new_user']         = 'nový používateľ:';
 $lang['mail_upload']           = 'nahraný súbor:';
 $lang['changes_type']          = 'Prehľad zmien';
 $lang['pages_changes']         = 'Stránok';
@@ -227,24 +262,21 @@ $lang['qb_sig']                = 'Vložiť podpis';
 $lang['qb_smileys']            = 'Smajlíky';
 $lang['qb_chars']              = 'Špeciálne znaky';
 $lang['upperns']               = 'návrat do nadradeného menného priestoru';
-$lang['admin_register']        = 'Pridaj nového užívateľa';
 $lang['metaedit']              = 'Upraviť metainformácie';
 $lang['metasaveerr']           = 'Zápis metainformácií zlyhal';
 $lang['metasaveok']            = 'Metainformácie uložené';
-$lang['img_backto']            = 'Späť na';
-$lang['img_title']             = 'Titul';
-$lang['img_caption']           = 'Popis';
-$lang['img_date']              = 'Dátum';
-$lang['img_fname']             = 'Názov súboru';
-$lang['img_fsize']             = 'Veľkosť';
-$lang['img_artist']            = 'Fotograf';
-$lang['img_copyr']             = 'Kopírovacie práva';
-$lang['img_format']            = 'Formát';
-$lang['img_camera']            = 'Fotoaparát';
-$lang['img_keywords']          = 'Kľúčové slová';
-$lang['img_width']             = 'Šírka';
-$lang['img_height']            = 'Výška';
-$lang['img_manager']           = 'Prezrieť v správcovi médií';
+$lang['img_title']             = 'Titul:';
+$lang['img_caption']           = 'Popis:';
+$lang['img_date']              = 'Dátum:';
+$lang['img_fname']             = 'Názov súboru:';
+$lang['img_fsize']             = 'Veľkosť:';
+$lang['img_artist']            = 'Fotograf:';
+$lang['img_copyr']             = 'Kopírovacie práva:';
+$lang['img_format']            = 'Formát:';
+$lang['img_camera']            = 'Fotoaparát:';
+$lang['img_keywords']          = 'Kľúčové slová:';
+$lang['img_width']             = 'Šírka:';
+$lang['img_height']            = 'Výška:';
 $lang['subscr_subscribe_success'] = 'Používateľ %s bol pridaný do zoznamu hlásení o zmenách %s';
 $lang['subscr_subscribe_error'] = 'Chyba pri pridaní používateľa %s do zoznamu hlásení o zmenách %s';
 $lang['subscr_subscribe_noaddress'] = 'Vaše prihlasovacie meno nemá priradenú žiadnu email adresu, nemôžete byť pridaný do zoznamu hlásení o zmenách';
@@ -261,9 +293,7 @@ $lang['subscr_m_receive']      = 'Dostávať';
 $lang['subscr_style_every']    = 'email pri každej zmene';
 $lang['subscr_style_digest']   = 'email so zhrnutím zmien pre každú stránku (perióda %.2f dňa)';
 $lang['subscr_style_list']     = 'zoznam zmenených stránok od posledného emailu (perióda %.2f dňa)';
-$lang['authmodfailed']         = 'Užívateľská autentifikácia nie je možná. Prosím informujte správcu systému.';
-$lang['authtempfail']          = 'Užívateľská autentifikácia je dočasne nedostupná. Ak táto situácia pretrváva, prosím informujte správcu systému.';
-$lang['authpwdexpire']         = 'Platnosť hesla vyprší za %d dní, mali by ste ho zmeniť čo najskôr.';
+$lang['authtempfail']          = 'Používateľská autentifikácia je dočasne nedostupná. Ak táto situácia pretrváva, prosím informujte správcu systému.';
 $lang['i_chooselang']          = 'Zvoľte váš jazyk';
 $lang['i_installer']           = 'DokuWiki inštalátor';
 $lang['i_wikiname']            = 'Názov Wiki';
@@ -273,6 +303,7 @@ $lang['i_problems']            = 'Inštalátor narazil na nižšie uvedené prob
 $lang['i_modified']            = 'Z bezpečnostných dôvodov bude tento skript fungovať iba s novou, neupravenou inštaláciou Dokuwiki. Môžete buď znovu rozbaliť stiahnutý inštalačný balík alebo preštudovať <a href="http://dokuwiki.org/install"> inštalačné inštrukcie Dokuwiki</a>';
 $lang['i_funcna']              = 'PHP funkcia <code>%s</code> nie je dostupná. Je možné, že ju z určitých dôvodov zablokoval váš poskytovateľ webhostingu?';
 $lang['i_phpver']              = 'Vaša verzia PHP <code>%s</code> je nižšia ako požadovaná <code>%s</code>. Potrebujete aktualizovať Vašu inštaláciu PHP.';
+$lang['i_mbfuncoverload']      = 'mbstring.func_overload musí byt zakázaná v php.ini pre bezproblémový chod DokuWiki.';
 $lang['i_permfail']            = '<code>%s</code> nie je zapisovateľný pre DokuWiki. Musíte zmeniť prístupové práva pre tento adresár!';
 $lang['i_confexists']          = '<code>%s</code> už existuje';
 $lang['i_writeerr']            = 'Nie je možné vytvoriť <code>%s</code>. Potrebujete skontrolovať prístupové práva pre adresár/súbor a vytvoriť ho manuálne.';
@@ -282,10 +313,14 @@ $lang['i_success']             = 'Konfigurácia bola úspešne ukončená. Teraz
 $lang['i_failure']             = 'Pri zápise konfiguračného súboru nastali nejaké chyby. Potrebujete ich opraviť manuálne pred tým, ako budete môcť používať <a href="doku.php?id=wiki:welcome">vašu novú DokuWiki</a>.';
 $lang['i_policy']              = 'Počiatočná ACL politika';
 $lang['i_pol0']                = 'Otvorená Wiki (čítanie, zápis a nahrávanie pre každého)';
-$lang['i_pol1']                = 'Verejná Wiki (čítanie pre každého, zápis a nahrávanie pre registrovaných užívateľov)';
-$lang['i_pol2']                = 'Uzatvorená Wiki (čítanie, zápis a nahrávanie len pre registrovaných užívateľov)';
+$lang['i_pol1']                = 'Verejná Wiki (čítanie pre každého, zápis a nahrávanie pre registrovaných používateľov)';
+$lang['i_pol2']                = 'Uzatvorená Wiki (čítanie, zápis a nahrávanie len pre registrovaných používateľov)';
+$lang['i_allowreg']            = 'Povolenie samostanej registrácie používateľov';
 $lang['i_retry']               = 'Skúsiť znovu';
 $lang['i_license']             = 'Vyberte licenciu, pod ktorou chcete uložiť váš obsah:';
+$lang['i_license_none']        = 'Nezobrazovať žiadne licenčné informácie';
+$lang['i_pop_field']           = 'Prosím pomôžte nám zlepšiť prácu s DokuWiki:';
+$lang['i_pop_label']           = 'Raz mesačne zaslať anonymné údaje vývojárom DokuWiki';
 $lang['recent_global']         = 'Práve prehliadate zmeny v mennom priestore <b>%s</b>. Môžete si tiež pozrieť <a href="%s">aktuálne zmeny celej wiki</a>.';
 $lang['years']                 = 'pred %d rokmi';
 $lang['months']                = 'pred %d mesiacmi';
@@ -318,3 +353,12 @@ $lang['media_perm_read']       = 'Prepáčte, ale nemáte dostatočné oprávnen
 $lang['media_perm_upload']     = 'Prepáčte, ale nemáte dostatočné oprávnenie na nahrávanie súborov.';
 $lang['media_update']          = 'Nahrať novú verziu';
 $lang['media_restore']         = 'Obnoviť túto verziu';
+$lang['media_acl_warning']     = 'Tento zoznam nemusí byť úplný z dôvodu ACL obmedzení alebo skratých stránok.';
+$lang['currentns']             = 'Aktuálny menný priestor';
+$lang['searchresult']          = 'Výsledky hľadania';
+$lang['plainhtml']             = 'Jednoduché HTML';
+$lang['wikimarkup']            = 'Wiki formát';
+$lang['page_nonexist_rev']     = 'Stránka %s neexistovala. Bola vytvorená dodatočne <a href="%s">%s</a>.';
+$lang['unable_to_parse_date']  = 'Nie je možné spracovať parameter "%s".';
+$lang['email_signature_text']  = 'Táto správa bola zaslaná DokuWiki
+@DOKUWIKIURL@';
