@@ -3,6 +3,7 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author Mac <mac@easterncyber.com>
  * @author Komgrit Niyomrath <n.komgrit@gmail.com>
  * @author Arthit Suriyawongkul <arthit@gmail.com>
  * @author Kittithat Arnontavilas <mrtomyum@gmail.com>
@@ -69,7 +70,62 @@ $lang['badpassconfirm']        = 'พาสเวิร์ดไม่ถูก
 $lang['minoredit']             = 'เป็นการแก้ไขเล็กน้อย';
 $lang['draftdate']             = 'บันทึกฉบับร่างเมื่อ';
 $lang['nosecedit']             = 'ในช่วงเวลาที่ผ่านมานี้เพจถูกแก้ไขไปแล้ว, เนื้อหาในเซคชั่นนี้ไม่ทันสมัย กรุณาโหลดเพจใหม่ทั้งหน้าแทน';
-$lang['searchcreatepage']      = 'ถ้าคุณไม่พบสิ่งที่คนมองหา คุณสามารถเลือกที่จะสร้าง หรือแก้ไขชื่อเพจหลังจากดูผลสืบค้นแล้วด้วยปุ่มที่เหมาะสม';
+$lang['searchcreatepage']      = 'หากคุณไม่พบสิ่งที่ต้องการ คุณสามารถสร้างหรือแก้ไขหน้า %s ซึ่งตั้งชื่อตามกระทู้ของคุณ';
+$lang['search_fullresults']    = 'ผลลัพธ์เต็มรูปแบบ';
+$lang['js']['search_toggle_tools'] = 'สลับเครื่องมือที่ใช้ค้นหา';
+$lang['js']['willexpire']      = 'การล๊อคเพื่อแก้ไขหน้านี้กำลังจะหมดเวลาในอีก \n นาที เพื่อที่จะหลีกเลี่ยงข้อขัดแย้งให้ใช้ปุ่ม "Preview" เพื่อรีเซ็ทเวลาใหม่';
+$lang['js']['notsavedyet']     = 'การแก้ไขที่ไม่ได้บันทึกจะสูญหาย \n ต้องการทำต่อจริงๆหรือ?';
+$lang['js']['searchmedia']     = 'ค้นหาไฟล์';
+$lang['js']['keepopen']        = 'เปิดหน้าต่างไว้ระหว่างที่เลือก';
+$lang['js']['hidedetails']     = 'ซ่อนรายละเอียด';
+$lang['js']['mediatitle']      = 'กำหนดข้อมูลลิงค์';
+$lang['js']['mediadisplay']    = 'ชนิดของลิงค์';
+$lang['js']['mediaalign']      = 'การจัดวาง';
+$lang['js']['mediasize']       = 'ขนาดรูปภาพ';
+$lang['js']['mediatarget']     = 'เป้าหมายของลิงค์';
+$lang['js']['mediaclose']      = 'ปิด';
+$lang['js']['mediainsert']     = 'แทรก';
+$lang['js']['mediadisplayimg'] = 'แสดงรูปภาพ';
+$lang['js']['mediadisplaylnk'] = 'แสดงลิงค์ เท่านั้น';
+$lang['js']['mediasmall']      = 'รูปแบบขนาดเล็ก';
+$lang['js']['mediamedium']     = 'รูปแบบขนาดกลาง';
+$lang['js']['medialarge']      = 'รูปแบบขนาดใหญ่';
+$lang['js']['mediaoriginal']   = 'รูปแบบตั้งต้น';
+$lang['js']['medialnk']        = 'ลิงค์ไปยังหน้ารายละเอียด';
+$lang['js']['mediadirect']     = 'ลิงค์ตรงไปที่ต้นฉบับ';
+$lang['js']['medianolnk']      = 'ไม่มีลิงค์';
+$lang['js']['medianolink']     = 'ไม่ลิงค์ไปยังภาพ';
+$lang['js']['medialeft']       = 'จัดเรียงภาพไว้ทางด้านซ้าย';
+$lang['js']['mediaright']      = 'จัดเรียงภาพไว้ทางด้านขวา';
+$lang['js']['mediacenter']     = 'จัดเรียงภาพไว้ตรงกลาง';
+$lang['js']['medianoalign']    = 'ไม่จัดเรียง';
+$lang['js']['nosmblinks']      = 'เชื่อมไปยังหน้าต่างแบ่งปัน ทำงานได้กับเฉพาะไมโครซอฟท์อินเตอร์เน็ตเอ็กซโปรเรอร์(IE) คุณยังคงสามารถคัดลอกและแปะลิ้งค์ได้';
+$lang['js']['linkwiz']         = 'ลิงค์วิเศษ';
+$lang['js']['linkto']          = 'ลิงค์ไป:';
+$lang['js']['del_confirm']     = 'ต้องการลบรายการที่เลือกจริงๆหรือ?';
+$lang['js']['restore_confirm'] = 'ต้องการกู้คืนเวอร์ชั่นนี้จริงๆ?';
+$lang['js']['media_diff']      = 'แสดงข้อแตกต่าง';
+$lang['js']['media_diff_both'] = 'เคียงบ่าเคียงไหล่';
+$lang['js']['media_diff_opacity'] = 'ส่องผ่าน';
+$lang['js']['media_diff_portions'] = 'ตีแรงๆ';
+$lang['js']['media_select']    = 'เลือกไฟล์...';
+$lang['js']['media_upload_btn'] = 'อัพโหลด';
+$lang['js']['media_done_btn']  = 'เสร็จแล้ว';
+$lang['js']['media_drop']      = 'วางไฟล์ตรงนี้เพื่อทำการอัพโหลด';
+$lang['js']['media_cancel']    = 'ลบออก';
+$lang['js']['media_overwrt']   = 'บันทึกไฟล์ใหม่ทับไฟล์เดิม';
+$lang['search_exact_match']    = 'คู่ที่เหมาะสม';
+$lang['search_starts_with']    = 'เริ่มต้นด้วย';
+$lang['search_ends_with']      = 'สิ้นสุดด้วย';
+$lang['search_contains']       = 'มี';
+$lang['search_custom_match']   = 'กำหนดเอง';
+$lang['search_any_ns']         = 'เนมสเปซใด ๆ';
+$lang['search_any_time']       = 'เวลาใดๆ';
+$lang['search_past_7_days']    = 'สัปดาห์ที่ผ่านมา';
+$lang['search_past_month']     = 'เดือนที่ผ่านมา';
+$lang['search_past_year']      = 'ปีที่ผ่านมา';
+$lang['search_sort_by_hits']   = 'เรียงตามความนิยม';
+$lang['search_sort_by_mtime']  = 'เรียงตามการแก้ไขครั้งล่าสุด';
 $lang['regmissing']            = 'ขออภัย คุณต้องกรอกให้ครบทุกช่อง';
 $lang['reguexists']            = 'ชื่อบัญชีที่ใส่นั้นมีผู้อื่นได้ใช้แล้ว กรุณาเลือกชื่อผู้ใช้อื่น';
 $lang['regsuccess']            = 'ผู้ใช้ถูกสร้างแล้ว และรหัสผ่านได้ถูกส่งไปทางอีเมลแล้ว';
@@ -108,28 +164,6 @@ $lang['txt_overwrt']           = 'เขียนทับไฟล์ที่
 $lang['maxuploadsize']         = 'อัพโหลด สูงสุด %s ต่อไฟล์';
 $lang['lockedby']              = 'ตอนนี้ถูกล๊อคโดย:';
 $lang['lockexpire']            = 'การล๊อคจะหมดอายุเมื่อ:';
-$lang['js']['willexpire']      = 'การล๊อคเพื่อแก้ไขหน้านี้กำลังจะหมดเวลาในอีก \n นาที เพื่อที่จะหลีกเลี่ยงข้อขัดแย้งให้ใช้ปุ่ม "Preview" เพื่อรีเซ็ทเวลาใหม่';
-$lang['js']['notsavedyet']     = 'การแก้ไขที่ไม่ได้บันทึกจะสูญหาย \n ต้องการทำต่อจริงๆหรือ?';
-$lang['js']['searchmedia']     = 'ค้นหาไฟล์';
-$lang['js']['keepopen']        = 'เปิดหน้าต่างไว้ระหว่างที่เลือก';
-$lang['js']['hidedetails']     = 'ซ่อนรายละเอียด';
-$lang['js']['mediatitle']      = 'กำหนดข้อมูลลิงค์';
-$lang['js']['mediadisplay']    = 'ชนิดของลิงค์';
-$lang['js']['mediaalign']      = 'การจัดวาง';
-$lang['js']['mediasize']       = 'ขนาดรูปภาพ';
-$lang['js']['mediatarget']     = 'เป้าหมายของลิงค์';
-$lang['js']['mediaclose']      = 'ปิด';
-$lang['js']['mediainsert']     = 'แทรก';
-$lang['js']['mediadisplayimg'] = 'แสดงรูปภาพ';
-$lang['js']['mediadisplaylnk'] = 'แสดงลิงค์ เท่านั้น';
-$lang['js']['mediasmall']      = 'รูปแบบขนาดเล็ก';
-$lang['js']['mediamedium']     = 'รูปแบบขนาดกลาง';
-$lang['js']['medialarge']      = 'รูปแบบขนาดใหญ่';
-$lang['js']['mediaoriginal']   = 'รูปแบบตั้งต้น';
-$lang['js']['nosmblinks']      = 'เชื่อมไปยังหน้าต่างแบ่งปัน ทำงานได้กับเฉพาะไมโครซอฟท์อินเตอร์เน็ตเอ็กซโปรเรอร์(IE) คุณยังคงสามารถคัดลอกและแปะลิ้งค์ได้';
-$lang['js']['linkwiz']         = 'ลิงค์วิเศษ';
-$lang['js']['linkto']          = 'ลิงค์ไป:';
-$lang['js']['del_confirm']     = 'ต้องการลบรายการที่เลือกจริงๆหรือ?';
 $lang['rssfailed']             = 'มีข้อผิดพลาดขณะดูดฟีดนี้';
 $lang['nothingfound']          = 'ไม่พบสิ่งใด';
 $lang['mediaselect']           = 'ไฟล์สื่อ';
@@ -146,6 +180,7 @@ $lang['deletefail']            = '"%s" ไม่สามารถลบได
 $lang['mediainuse']            = 'ไฟล์ "%s" ไม่ได้ถูกลบ - มันถูกใช้อยู่';
 $lang['namespaces']            = 'เนมสเปซ';
 $lang['mediafiles']            = 'มีไฟล์พร้อมใช้อยู่ใน';
+$lang['accessdenied']          = 'คุณไม่ได้รับสิทธิ์ในการดูหน้าเพจนี้';
 $lang['mediausage']            = 'ให้ใช้ไวยกรณ์ต่อไปนี้เพื่ออ้างอิงไฟล์นี้';
 $lang['mediaview']             = 'ดูไฟล์ต้นฉบับ';
 $lang['mediaroot']             = 'ราก(รูท)';
@@ -161,6 +196,15 @@ $lang['current']               = 'ฉบับปัจจุบัน';
 $lang['yours']                 = 'ฉบับของคุณ';
 $lang['diff']                  = 'แสดงจุดแตกต่างกับฉบับปัจจุบัน';
 $lang['diff2']                 = 'แสดงจุดแตกต่างระหว่างฉบับที่เลือกไว้';
+$lang['difflink']              = 'ลิงค์ไปยังการเปรียบเทียบนี้';
+$lang['diff_type']             = 'ดูความแตกต่าง:';
+$lang['diff_inline']           = 'อยู่ในไลน์';
+$lang['diff_side']             = 'เคียงบ่าเคียงไหล่';
+$lang['diffprevrev']           = 'การแก้ไขก่อนหน้า';
+$lang['diffnextrev']           = 'การแก้ไขถัดไป';
+$lang['difflastrev']           = 'การแก้ไขล่าสุด';
+$lang['diffbothprevrev']       = 'การแก้ไขก่อนหน้าทั้งสองฝั่ง';
+$lang['diffbothnextrev']       = 'การแก้ไขถัดไปทั้งสองฝั่ง';
 $lang['line']                  = 'บรรทัด';
 $lang['breadcrumb']            = 'ตามรอย:';
 $lang['youarehere']            = 'คุณอยู่ที่นี่:';
@@ -173,10 +217,21 @@ $lang['external_edit']         = 'แก้ไขภายนอก';
 $lang['summary']               = 'สรุป(หมายเหตุ)การแก้ไขนี้';
 $lang['noflash']               = 'ต้องการตัวเล่นแฟลช <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> เพื่อแสดงผลเนื้อหานี้';
 $lang['download']              = 'ดาวน์โหลดสนิปเป็ด(Snippet)';
+$lang['tools']                 = 'เครื่องมือ';
+$lang['user_tools']            = 'เครื่องมือสำหรับผู้ใช้';
+$lang['site_tools']            = 'เครื่องมือของไซต์';
+$lang['page_tools']            = 'เครื่องมือของหน้าเพจ';
+$lang['skip_to_content']       = 'ข้ามไปยังเนื้อหา';
+$lang['sidebar']               = 'แถบด้านข้าง';
 $lang['mail_newpage']          = 'เพิ่มเพจแล้ว:';
 $lang['mail_changed']          = 'แก้ไขเพจแล้ว:';
+$lang['mail_subscribe_list']   = 'หน้าที่เปลี่นแปลงในเนมสเปซ';
 $lang['mail_new_user']         = 'ผู้ใช้คนใหม่:';
 $lang['mail_upload']           = 'ไฟล์อัพโหลดแล้ว:';
+$lang['changes_type']          = 'ดูการเปลี่ยนแปลงของ';
+$lang['pages_changes']         = 'หน้าเพจ';
+$lang['media_changes']         = 'ไฟล์มีเดีย';
+$lang['both_changes']          = 'ทั้งสองหน้าและมีเดียไฟล์';
 $lang['qb_bold']               = 'ทำตัวหนา';
 $lang['qb_italic']             = 'ทำตัวเอียง';
 $lang['qb_underl']             = 'ขีดเส้นใต้ข้อความ';
@@ -215,6 +270,11 @@ $lang['img_copyr']             = 'ผู้ถือลิขสิทธิ์:
 $lang['img_format']            = 'รูปแบบ:';
 $lang['img_camera']            = 'กล้อง:';
 $lang['img_keywords']          = 'คำหลัก:';
+$lang['img_width']             = 'ความกว้าง:';
+$lang['img_height']            = 'ความสูง:';
+$lang['subscr_subscribe_success'] = 'เพิ่ม %s ในรายการสมัครสมาชิก สำหรับ %s';
+$lang['subscr_subscribe_error'] = 'เกิดข้อผิดพลาดในการเพิ่ม %s ในรายการสมัครสมาชิก สำหรับ %s';
+$lang['subscr_subscribe_noaddress'] = 'ไม่มีที่อยู่ที่เกี่ยวข้องกับการเข้าสู่ระบบของคุณ จึงไม่สามารถเพิ่มลงในรายการสมัครสมาชิก';
 $lang['authtempfail']          = 'ระบบตรวจสอบสิทธิ์ผู้ใช้ไม่พร้อมใช้งานชั่วคราว หากสถานการณ์ยังไม่เปลี่ยนแปลง กรุณาแจ้งผู้ดูแลระบวิกิของคุณ';
 $lang['i_chooselang']          = 'เลือกภาษาของคุณ';
 $lang['i_installer']           = 'ตัวติดตั้งโดกุวิกิ';
@@ -242,5 +302,5 @@ $lang['days']                  = '%d วันก่อน';
 $lang['hours']                 = '%d ชั่วโมงก่อน';
 $lang['minutes']               = '%d นาทีก่อน';
 $lang['seconds']               = '%d วินาทีก่อน';
-$lang['email_signature_text'] = 'จดหมายนี้ถูกสร้างขึ้นโดยโดกุวิกิที่
+$lang['email_signature_text']  = 'จดหมายนี้ถูกสร้างขึ้นโดยโดกุวิกิที่
 @DOKUWIKIURL@';
