@@ -7,7 +7,12 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
-if(!defined('DOKU_INC')) die('meh.');
+use dokuwiki\Cache\CacheInstructions;
+use dokuwiki\Cache\CacheRenderer;
+use dokuwiki\ChangeLog\PageChangeLog;
+use dokuwiki\Extension\PluginController;
+use dokuwiki\Extension\Event;
+use dokuwiki\Parsing\Parser;
 
 /**
  * How many pages shall be rendered for getting metadata during one request
@@ -55,8 +60,15 @@ define('METADATA_RENDER_UNLIMITED', 4);
  * wasn't found
  *
  * @author Andreas Gohr <andi@splitbrain.org>
+ *
+ * @param string $id page id
+ * @param string|int $rev revision timestamp or empty string
+ * @param bool $excuse
+ * @param string $date_at
+ *
+ * @return null|string
  */
-function p_wiki_xhtml($id, $rev='', $excuse=true){
+function p_wiki_xhtml($id, $rev='', $excuse=true,$date_at=''){
     $file = wikiFN($id,$rev);
     $ret  = '';
 
@@ -65,17 +77,24 @@ function p_wiki_xhtml($id, $rev='', $excuse=true){
     $keep = $ID;
     $ID   = $id;
 
-    if($rev){
-        if(@file_exists($file)){
-            $ret = p_render('xhtml',p_get_instructions(io_readWikiPage($file,$id,$rev)),$info); //no caching on old revisions
+    if($rev || $date_at){
+        if(file_exists($file)){
+            //no caching on old revisions
+            $ret = p_render('xhtml',p_get_instructions(io_readWikiPage($file,$id,$rev)),$info,$date_at);
         }elseif($excuse){
             $ret = p_locale_xhtml('norev');
         }
     }else{
-        if(@file_exists($file)){
+        if(file_exists($file)){
             $ret = p_cached_output($file,'xhtml',$id);
         }elseif($excuse){
-            $ret = p_locale_xhtml('newpage');
+            //check if the page once existed
+            $changelog = new PageChangeLog($id);
+            if($changelog->hasRevisions()) {
+                $ret = p_locale_xhtml('onceexisted');
+            } else {
+                $ret = p_locale_xhtml('newpage');
+            }
         }
     }
 
@@ -89,6 +108,9 @@ function p_wiki_xhtml($id, $rev='', $excuse=true){
  * Returns the specified local text in parsed format
  *
  * @author Andreas Gohr <andi@splitbrain.org>
+ *
+ * @param string $id page id
+ * @return null|string
  */
 function p_locale_xhtml($id){
     //fetch parsed locale
@@ -101,23 +123,33 @@ function p_locale_xhtml($id){
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Chris Smith <chris@jalakai.co.uk>
+ *
+ * @param string $file filename, path to file
+ * @param string $format
+ * @param string $id page id
+ * @return null|string
  */
 function p_cached_output($file, $format='xhtml', $id='') {
     global $conf;
 
-    $cache = new cache_renderer($id, $file, $format);
+    $cache = new CacheRenderer($id, $file, $format);
     if ($cache->useCache()) {
         $parsed = $cache->retrieveCache(false);
-        if($conf['allowdebug'] && $format=='xhtml') $parsed .= "\n<!-- cachefile {$cache->cache} used -->\n";
+        if($conf['allowdebug'] && $format=='xhtml') {
+            $parsed .= "\n<!-- cachefile {$cache->cache} used -->\n";
+        }
     } else {
         $parsed = p_render($format, p_cached_instructions($file,false,$id), $info);
 
-        if ($info['cache']) {
-            $cache->storeCache($parsed);               //save cachefile
-            if($conf['allowdebug'] && $format=='xhtml') $parsed .= "\n<!-- no cachefile used, but created {$cache->cache} -->\n";
+        if ($info['cache'] && $cache->storeCache($parsed)) {              // storeCache() attempts to save cachefile
+            if($conf['allowdebug'] && $format=='xhtml') {
+                $parsed .= "\n<!-- no cachefile used, but created {$cache->cache} -->\n";
+            }
         }else{
             $cache->removeCache();                     //try to delete cachefile
-            if($conf['allowdebug'] && $format=='xhtml') $parsed .= "\n<!-- no cachefile used, caching forbidden -->\n";
+            if($conf['allowdebug'] && $format=='xhtml') {
+                $parsed .= "\n<!-- no cachefile used, caching forbidden -->\n";
+            }
         }
     }
 
@@ -130,16 +162,21 @@ function p_cached_output($file, $format='xhtml', $id='') {
  * Uses and creates a serialized cache file
  *
  * @author Andreas Gohr <andi@splitbrain.org>
+ *
+ * @param string $file      filename, path to file
+ * @param bool   $cacheonly
+ * @param string $id        page id
+ * @return array|null
  */
 function p_cached_instructions($file,$cacheonly=false,$id='') {
     static $run = null;
     if(is_null($run)) $run = array();
 
-    $cache = new cache_instructions($id, $file);
+    $cache = new CacheInstructions($id, $file);
 
     if ($cacheonly || $cache->useCache() || (isset($run[$file]) && !defined('DOKU_UNITTEST'))) {
         return $cache->retrieveCache();
-    } else if (@file_exists($file)) {
+    } else if (file_exists($file)) {
         // no cache - do some work
         $ins = p_get_instructions(io_readWikiPage($file,$id));
         if ($cache->storeCache($ins)) {
@@ -158,16 +195,16 @@ function p_cached_instructions($file,$cacheonly=false,$id='') {
  *
  * @author Harry Fuecks <hfuecks@gmail.com>
  * @author Andreas Gohr <andi@splitbrain.org>
+ *
+ * @param string $text  raw wiki syntax text
+ * @return array a list of instruction arrays
  */
 function p_get_instructions($text){
 
     $modes = p_get_parsermodes();
 
-    // Create the parser
-    $Parser = new Doku_Parser();
-
-    // Add the Handler
-    $Parser->Handler = new Doku_Handler();
+    // Create the parser and handler
+    $Parser = new Parser(new Doku_Handler());
 
     //add modes to parser
     foreach($modes as $mode){
@@ -175,7 +212,7 @@ function p_get_instructions($text){
     }
 
     // Do the parsing
-    trigger_event('PARSER_WIKITEXT_PREPROCESS', $text);
+    Event::createAndTrigger('PARSER_WIKITEXT_PREPROCESS', $text);
     $p = $Parser->parse($text);
     //  dbg($p);
     return $p;
@@ -184,9 +221,10 @@ function p_get_instructions($text){
 /**
  * returns the metadata of a page
  *
- * @param string $id The id of the page the metadata should be returned from
- * @param string $key The key of the metdata value that shall be read (by default everything) - separate hierarchies by " " like "date created"
- * @param int $render If the page should be rendererd - possible values:
+ * @param string $id      The id of the page the metadata should be returned from
+ * @param string $key     The key of the metdata value that shall be read (by default everything)
+ *                        separate hierarchies by " " like "date created"
+ * @param int    $render  If the page should be rendererd - possible values:
  *     METADATA_DONT_RENDER, METADATA_RENDER_USING_SIMPLE_CACHE, METADATA_RENDER_USING_CACHE
  *     METADATA_RENDER_UNLIMITED (also combined with the previous two options),
  *     default: METADATA_RENDER_USING_CACHE
@@ -221,14 +259,14 @@ function p_get_metadata($id, $key='', $render=METADATA_RENDER_USING_CACHE){
     if (!$recursion && $render != METADATA_DONT_RENDER && !isset($rendered_pages[$id])&& page_exists($id)){
         $recursion = true;
 
-        $cachefile = new cache_renderer($id, wikiFN($id), 'metadata');
+        $cachefile = new CacheRenderer($id, wikiFN($id), 'metadata');
 
         $do_render = false;
         if ($render & METADATA_RENDER_UNLIMITED || $render_count < P_GET_METADATA_RENDER_LIMIT) {
             if ($render & METADATA_RENDER_USING_SIMPLE_CACHE) {
                 $pagefn = wikiFN($id);
                 $metafn = metaFN($id, '.meta');
-                if (!@file_exists($metafn) || @filemtime($pagefn) > @filemtime($cachefile->cache)) {
+                if (!file_exists($metafn) || @filemtime($pagefn) > @filemtime($cachefile->cache)) {
                     $do_render = true;
                 }
             } elseif (!$cachefile->useCache()){
@@ -272,10 +310,10 @@ function p_get_metadata($id, $key='', $render=METADATA_RENDER_USING_CACHE){
  *
  * @see http://www.dokuwiki.org/devel:metadata#functions_to_get_and_set_metadata
  *
- * @param String  $id         is the ID of a wiki page
- * @param Array   $data       is an array with key ⇒ value pairs to be set in the metadata
- * @param Boolean $render     whether or not the page metadata should be generated with the renderer
- * @param Boolean $persistent indicates whether or not the particular metadata value will persist through
+ * @param string  $id         is the ID of a wiki page
+ * @param array   $data       is an array with key ⇒ value pairs to be set in the metadata
+ * @param boolean $render     whether or not the page metadata should be generated with the renderer
+ * @param boolean $persistent indicates whether or not the particular metadata value will persist through
  *                            the next metadata rendering.
  * @return boolean true on success
  *
@@ -309,13 +347,16 @@ function p_set_metadata($id, $data, $render=false, $persistent=true){
 
             foreach ($value as $subkey => $subvalue){
                 if(isset($meta['current'][$key][$subkey]) && is_array($meta['current'][$key][$subkey])) {
-                    $meta['current'][$key][$subkey] = array_merge($meta['current'][$key][$subkey], (array)$subvalue);
+                    $meta['current'][$key][$subkey] = array_replace($meta['current'][$key][$subkey], (array)$subvalue);
                 } else {
                     $meta['current'][$key][$subkey] = $subvalue;
                 }
                 if($persistent) {
                     if(isset($meta['persistent'][$key][$subkey]) && is_array($meta['persistent'][$key][$subkey])) {
-                        $meta['persistent'][$key][$subkey] = array_merge($meta['persistent'][$key][$subkey], (array)$subvalue);
+                        $meta['persistent'][$key][$subkey] = array_replace(
+                            $meta['persistent'][$key][$subkey],
+                            (array) $subvalue
+                        );
                     } else {
                         $meta['persistent'][$key][$subkey] = $subvalue;
                     }
@@ -327,10 +368,14 @@ function p_set_metadata($id, $data, $render=false, $persistent=true){
 
             // these keys, must have subkeys - a legitimate value must be an array
             if (is_array($value)) {
-                $meta['current'][$key] = !empty($meta['current'][$key]) ? array_merge((array)$meta['current'][$key],$value) : $value;
+                $meta['current'][$key] = !empty($meta['current'][$key]) ?
+                    array_replace((array)$meta['current'][$key],$value) :
+                    $value;
 
                 if ($persistent) {
-                    $meta['persistent'][$key] = !empty($meta['persistent'][$key]) ? array_merge((array)$meta['persistent'][$key],$value) : $value;
+                    $meta['persistent'][$key] = !empty($meta['persistent'][$key]) ?
+                        array_replace((array)$meta['persistent'][$key],$value) :
+                        $value;
                 }
             }
 
@@ -359,6 +404,9 @@ function p_set_metadata($id, $data, $render=false, $persistent=true){
  * used on page deletion
  *
  * @author Michael Klier <chi@chimeric.de>
+ *
+ * @param string $id page id
+ * @return bool  success / fail
  */
 function p_purge_metadata($id) {
     $meta = p_read_metadata($id);
@@ -391,7 +439,9 @@ function p_read_metadata($id,$cache=false) {
     if (isset($cache_metadata[(string)$id])) return $cache_metadata[(string)$id];
 
     $file = metaFN($id, '.meta');
-    $meta = @file_exists($file) ? unserialize(io_readFile($file, false)) : array('current'=>array(),'persistent'=>array());
+    $meta = file_exists($file) ?
+        unserialize(io_readFile($file, false)) :
+        array('current'=>array(),'persistent'=>array());
 
     if ($cache) {
         $cache_metadata[(string)$id] = $meta;
@@ -422,14 +472,19 @@ function p_save_metadata($id, $meta) {
  * renders the metadata of a page
  *
  * @author Esther Brunner <esther@kaffeehaus.ch>
+ *
+ * @param string $id    page id
+ * @param array  $orig  the original metadata
+ * @return array|null array('current'=> array,'persistent'=> array);
  */
 function p_render_metadata($id, $orig){
     // make sure the correct ID is in global ID
     global $ID, $METADATA_RENDERERS;
 
     // avoid recursive rendering processes for the same id
-    if (isset($METADATA_RENDERERS[$id]))
+    if (isset($METADATA_RENDERERS[$id])) {
         return $orig;
+    }
 
     // store the original metadata in the global $METADATA_RENDERERS so p_set_metadata can use it
     $METADATA_RENDERERS[$id] =& $orig;
@@ -439,11 +494,9 @@ function p_render_metadata($id, $orig){
 
     // add an extra key for the event - to tell event handlers the page whose metadata this is
     $orig['page'] = $id;
-    $evt = new Doku_Event('PARSER_METADATA_RENDER', $orig);
+    $evt = new Event('PARSER_METADATA_RENDER', $orig);
     if ($evt->advise_before()) {
 
-        require_once DOKU_INC."inc/parser/metadata.php";
-
         // get instructions
         $instructions = p_cached_instructions(wikiFN($id),false,$id);
         if(is_null($instructions)){
@@ -477,6 +530,8 @@ function p_render_metadata($id, $orig){
  * returns all available parser syntax modes in correct order
  *
  * @author Andreas Gohr <andi@splitbrain.org>
+ *
+ * @return array[] with for each plugin the array('sort' => sortnumber, 'mode' => mode string, 'obj'  => plugin object)
  */
 function p_get_parsermodes(){
     global $conf;
@@ -500,7 +555,7 @@ function p_get_parsermodes(){
         global $PARSER_MODES;
         $obj = null;
         foreach($pluginlist as $p){
-            /** @var DokuWiki_Syntax_Plugin $obj */
+            /** @var \dokuwiki\Extension\SyntaxPlugin $obj */
             if(!$obj = plugin_load('syntax',$p)) continue; //attempt to load plugin into $obj
             $PARSER_MODES[$obj->getType()][] = "plugin_$p"; //register mode type
             //add to modes
@@ -524,7 +579,7 @@ function p_get_parsermodes(){
         $std_modes[] = 'multiplyentity';
     }
     foreach($std_modes as $m){
-        $class = "Doku_Parser_Mode_$m";
+        $class = 'dokuwiki\\Parsing\\ParserMode\\'.ucfirst($m);
         $obj   = new $class();
         $modes[] = array(
                 'sort' => $obj->getSort(),
@@ -537,7 +592,7 @@ function p_get_parsermodes(){
     $fmt_modes = array('strong','emphasis','underline','monospace',
             'subscript','superscript','deleted');
     foreach($fmt_modes as $m){
-        $obj   = new Doku_Parser_Mode_formatting($m);
+        $obj   = new \dokuwiki\Parsing\ParserMode\Formatting($m);
         $modes[] = array(
                 'sort' => $obj->getSort(),
                 'mode' => $m,
@@ -546,16 +601,16 @@ function p_get_parsermodes(){
     }
 
     // add modes which need files
-    $obj     = new Doku_Parser_Mode_smiley(array_keys(getSmileys()));
+    $obj     = new \dokuwiki\Parsing\ParserMode\Smiley(array_keys(getSmileys()));
     $modes[] = array('sort' => $obj->getSort(), 'mode' => 'smiley','obj'  => $obj );
-    $obj     = new Doku_Parser_Mode_acronym(array_keys(getAcronyms()));
+    $obj     = new \dokuwiki\Parsing\ParserMode\Acronym(array_keys(getAcronyms()));
     $modes[] = array('sort' => $obj->getSort(), 'mode' => 'acronym','obj'  => $obj );
-    $obj     = new Doku_Parser_Mode_entity(array_keys(getEntities()));
+    $obj     = new \dokuwiki\Parsing\ParserMode\Entity(array_keys(getEntities()));
     $modes[] = array('sort' => $obj->getSort(), 'mode' => 'entity','obj'  => $obj );
 
     // add optional camelcase mode
     if($conf['camelcase']){
-        $obj     = new Doku_Parser_Mode_camelcaselink();
+        $obj     = new \dokuwiki\Parsing\ParserMode\Camelcaselink();
         $modes[] = array('sort' => $obj->getSort(), 'mode' => 'camelcaselink','obj'  => $obj );
     }
 
@@ -569,6 +624,10 @@ function p_get_parsermodes(){
  * Callback function for usort
  *
  * @author Andreas Gohr <andi@splitbrain.org>
+ *
+ * @param array $a
+ * @param array $b
+ * @return int $a is lower/equal/higher than $b
  */
 function p_sort_modes($a, $b){
     if($a['sort'] == $b['sort']) return 0;
@@ -582,15 +641,26 @@ function p_sort_modes($a, $b){
  *
  * @author Harry Fuecks <hfuecks@gmail.com>
  * @author Andreas Gohr <andi@splitbrain.org>
+ *
+ * @param string $mode
+ * @param array|null|false $instructions
+ * @param array $info returns render info like enabled toc and cache
+ * @param string $date_at
+ * @return null|string rendered output
  */
-function p_render($mode,$instructions,&$info){
+function p_render($mode,$instructions,&$info,$date_at=''){
     if(is_null($instructions)) return '';
+    if($instructions === false) return '';
 
-    $Renderer =& p_get_renderer($mode);
+    $Renderer = p_get_renderer($mode);
     if (is_null($Renderer)) return null;
 
     $Renderer->reset();
 
+    if($date_at) {
+        $Renderer->date_at = $date_at;
+    }
+
     $Renderer->smileys = getSmileys();
     $Renderer->entities = getEntities();
     $Renderer->acronyms = getAcronyms();
@@ -609,50 +679,59 @@ function p_render($mode,$instructions,&$info){
 
     // Post process and return the output
     $data = array($mode,& $Renderer->doc);
-    trigger_event('RENDERER_CONTENT_POSTPROCESS',$data);
+    Event::createAndTrigger('RENDERER_CONTENT_POSTPROCESS',$data);
     return $Renderer->doc;
 }
 
 /**
- * @param $mode string Mode of the renderer to get
+ * Figure out the correct renderer class to use for $mode,
+ * instantiate and return it
+ *
+ * @param string $mode Mode of the renderer to get
  * @return null|Doku_Renderer The renderer
+ *
+ * @author Christopher Smith <chris@jalakai.co.uk>
  */
-function & p_get_renderer($mode) {
-    /** @var Doku_Plugin_Controller $plugin_controller */
+function p_get_renderer($mode) {
+    /** @var PluginController $plugin_controller */
     global $conf, $plugin_controller;
 
     $rname = !empty($conf['renderer_'.$mode]) ? $conf['renderer_'.$mode] : $mode;
     $rclass = "Doku_Renderer_$rname";
 
+    // if requested earlier or a bundled renderer
     if( class_exists($rclass) ) {
-        return new $rclass();
-    }
-
-    // try default renderer first:
-    $file = DOKU_INC."inc/parser/$rname.php";
-    if(@file_exists($file)){
-        require_once $file;
-
-        if ( !class_exists($rclass) ) {
-            trigger_error("Unable to resolve render class $rclass",E_USER_WARNING);
-            msg("Renderer '$rname' for $mode not valid",-1);
-            return null;
-        }
         $Renderer = new $rclass();
-    }else{
-        // Maybe a plugin/component is available?
-        list($plugin, $component) = $plugin_controller->_splitName($rname);
-        if (!$plugin_controller->isdisabled($plugin)){
-            $Renderer =& $plugin_controller->load('renderer',$rname);
-        }
-
-        if(!isset($Renderer) || is_null($Renderer)){
-            msg("No renderer '$rname' found for mode '$mode'",-1);
-            return null;
-        }
+        return $Renderer;
     }
 
-    return $Renderer;
+    // not bundled, see if its an enabled renderer plugin & when $mode is 'xhtml', the renderer can supply that format.
+    /** @var Doku_Renderer $Renderer */
+    $Renderer = $plugin_controller->load('renderer',$rname);
+    if ($Renderer && is_a($Renderer, 'Doku_Renderer')  && ($mode != 'xhtml' || $mode == $Renderer->getFormat())) {
+        return $Renderer;
+    }
+
+    // there is a configuration error!
+    // not bundled, not a valid enabled plugin, use $mode to try to fallback to a bundled renderer
+    $rclass = "Doku_Renderer_$mode";
+    if ( class_exists($rclass) ) {
+        // viewers should see renderered output, so restrict the warning to admins only
+        $msg = "No renderer '$rname' found for mode '$mode', check your plugins";
+        if ($mode == 'xhtml') {
+            $msg .= " and the 'renderer_xhtml' config setting";
+        }
+        $msg .= ".<br/>Attempting to fallback to the bundled renderer.";
+        msg($msg,-1,'','',MSG_ADMINS_ONLY);
+
+        $Renderer = new $rclass;
+        $Renderer->nocache();     // fallback only (and may include admin alerts), don't cache
+        return $Renderer;
+    }
+
+    // fallback failed, alert the world
+    msg("No renderer '$rname' found for mode '$mode'",-1);
+    return null;
 }
 
 /**
@@ -665,8 +744,8 @@ function & p_get_renderer($mode) {
  *                                              METADATA_RENDER_USING_SIMPLE_CACHE,
  *                                              METADATA_RENDER_USING_CACHE,
  *                                              METADATA_RENDER_UNLIMITED
- *
  * @return string|null The first heading
+ *
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Michael Hamann <michael@content-space.de>
  */
@@ -680,33 +759,39 @@ function p_get_first_heading($id, $render=METADATA_RENDER_USING_SIMPLE_CACHE){
  * @param  string   $code       source code to be highlighted
  * @param  string   $language   language to provide highlighting
  * @param  string   $wrapper    html element to wrap the returned highlighted text
- *
  * @return string xhtml code
+ *
  * @author Christopher Smith <chris@jalakai.co.uk>
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function p_xhtml_cached_geshi($code, $language, $wrapper='pre') {
+function p_xhtml_cached_geshi($code, $language, $wrapper='pre', array $options=null) {
     global $conf, $config_cascade, $INPUT;
     $language = strtolower($language);
 
     // remove any leading or trailing blank lines
     $code = preg_replace('/^\s*?\n|\s*?\n$/','',$code);
 
-    $cache = getCacheName($language.$code,".code");
+    $optionsmd5 = md5(serialize($options));
+    $cache = getCacheName($language.$code.$optionsmd5,".code");
     $ctime = @filemtime($cache);
     if($ctime && !$INPUT->bool('purge') &&
-            $ctime > filemtime(DOKU_INC.'inc/geshi.php') &&                 // geshi changed
-            $ctime > @filemtime(DOKU_INC.'inc/geshi/'.$language.'.php') &&  // language syntax definition changed
+            $ctime > filemtime(DOKU_INC.'vendor/composer/installed.json') &&  // libraries changed
             $ctime > filemtime(reset($config_cascade['main']['default']))){ // dokuwiki changed
         $highlighted_code = io_readFile($cache, false);
-
     } else {
 
-        $geshi = new GeSHi($code, $language, DOKU_INC . 'inc/geshi');
+        $geshi = new GeSHi($code, $language);
         $geshi->set_encoding('utf-8');
         $geshi->enable_classes();
         $geshi->set_header_type(GESHI_HEADER_PRE);
         $geshi->set_link_target($conf['target']['extern']);
+        if($options !== null) {
+            foreach ($options as $function => $params) {
+                if(is_callable(array($geshi, $function))) {
+                    $geshi->$function($params);
+                }
+            }
+        }
 
         // remove GeSHi's wrapper element (we'll replace it with our own later)
         // we need to use a GeSHi wrapper to avoid <BR> throughout the highlighted text
