@@ -21,14 +21,14 @@ if(file_exists(DOKU_INC.'favicon.ico')){
 }elseif(file_exists(tpl_incdir().'favicon.ico')){
     $ico = DOKU_URL.'lib/tpl/'.$conf['template'].'/favicon.ico';
 }else{
-    $ico = DOKU_URL.'lib/tpl/default/images/favicon.ico';
+    $ico = DOKU_URL.'lib/tpl/dokuwiki/images/favicon.ico';
 }
 
 // output
 header('Content-Type: application/opensearchdescription+xml; charset=utf-8');
 echo '<?xml version="1.0"?>'.NL;
 echo '<OpenSearchDescription xmlns="http://a9.com/-/spec/opensearch/1.1/">'.NL;
-echo '  <ShortName>'.htmlspecialchars($conf['title']).'</ShortName>'.NL;
+echo '  <ShortName>'.hsc($conf['title']).'</ShortName>'.NL;
 echo '  <Image width="16" height="16" type="image/x-icon">'.$ico.'</Image>'.NL;
 echo '  <Url type="text/html" template="'.DOKU_URL.DOKU_SCRIPT.'?do=search&amp;id={searchTerms}" />'.NL;
 echo '  <Url type="application/x-suggestions+json" template="'.
