@@ -3,9 +3,10 @@
 /**
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
+ * @author HokkaidoPerson <dosankomali@yahoo.co.jp>
  * @author Hideaki SAWADA <chuno@live.jp>
  */
-$lang['userexists']            = 'このユーザー名は既に存在しています。';
-$lang['usernotexists']         = 'このユーザーは未登録です。';
+$lang['userexists']            = '恐れ入りますが、このユーザー名は既に存在しています。';
+$lang['usernotexists']         = '恐れ入りますが、このユーザーは未登録です。';
 $lang['writefail']             = 'ユーザーデータを変更できません。管理者に問い合わせてください。';
 $lang['protected']             = 'ユーザ %s のデータは保護されており、変更・削除はできません。';
