@@ -1,10 +1,11 @@
 <?php
+
 /**
- * Serbian language file
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
- * @author Иван Петровић petrovicivan@ubuntusrbija.org
- * @author Ivan Petrovic <petrovicivan@ubuntusrbija.org>
+ * @author Иван Петровић <petrovicivan@ubuntusrbija.org>
  * @author Miroslav Šolti <solti.miroslav@gmail.com>
+ * @author Марко М. Костић <marko.m.kostic@gmail.com>
  */
 $lang['menu']                  = 'Подешавања';
 $lang['error']                 = 'Подешавања нису прихваћена јер постоји вредност са грешком, проверите измене које сте извршили и поновите слање.<br />Вредност(и) са грешком су приказане са црвеним оквиром.';
@@ -28,30 +29,29 @@ $lang['_links']                = 'Подешавања линковања';
 $lang['_media']                = 'Подешавања медија';
 $lang['_advanced']             = 'Напредна подешавања';
 $lang['_network']              = 'Подешавања мреже';
-$lang['_plugin_sufix']         = 'Подешавања за додатке';
-$lang['_template_sufix']       = 'Подешавања за шаблоне';
 $lang['_msg_setting_undefined'] = 'Нема метаподатака подешавања';
 $lang['_msg_setting_no_class'] = 'Нема класе подешавања';
 $lang['_msg_setting_no_default'] = 'Нема подразумеване вредности';
-$lang['fmode']                 = 'Начин прављења датотека';
-$lang['dmode']                 = 'Начин прављења фасцикла';
-$lang['lang']                  = 'Језик';
-$lang['basedir']               = 'Основна фасцикла';
-$lang['baseurl']               = 'Основни УРЛ';
-$lang['savedir']               = 'Фасцикла у којој ће се чувати подаци';
-$lang['start']                 = 'Назив почетне странице';
 $lang['title']                 = 'Назив викија';
+$lang['start']                 = 'Назив почетне странице';
+$lang['lang']                  = 'Језик';
 $lang['template']              = 'Шаблон';
 $lang['license']               = 'Под којом лиценцом желите да ваш материјал буде објављен?';
-$lang['fullpath']              = 'Објави целу путању странице у заглављу на дну стране';
+$lang['savedir']               = 'Фасцикла у којој ће се чувати подаци';
+$lang['basedir']               = 'Основна фасцикла';
+$lang['baseurl']               = 'Основни УРЛ';
+$lang['dmode']                 = 'Начин прављења фасцикла';
+$lang['fmode']                 = 'Начин прављења датотека';
+$lang['allowdebug']            = 'Укључи дебаговање <b>искључи ако није потребно!</b>';
 $lang['recent']                = 'Последње промене';
+$lang['recent_days']           = 'Колико последњих промена чувати (дани)';
 $lang['breadcrumbs']           = 'Број пређених корака (страница)';
 $lang['youarehere']            = 'Хиерархијске кораке (странице)';
+$lang['fullpath']              = 'Објави целу путању странице у заглављу на дну стране';
 $lang['typography']            = 'Уради типографске замене';
-$lang['htmlok']                = 'Дозволи угњежђени ХТМЛ';
-$lang['phpok']                 = 'Дозволи угњежђени ПХП';
-$lang['dformat']               = 'Облик датума (погледајте ПХПову <a href="http://www.php.net/strftime">strftime</a> функцију)';
+$lang['dformat']               = 'Облик датума (погледајте ПХПову <a href="http://php.net/strftime">strftime</a> функцију)';
 $lang['signature']             = 'Потпис';
+$lang['showuseras']            = 'Шта приказати за исписивање корисника који је последњи вршио измене';
 $lang['toptoclevel']           = 'Највиши ниво за садржај';
 $lang['tocminheads']           = 'Минималан број наслова који одређују да ли ће Садржај бити направљен';
 $lang['maxtoclevel']           = 'Максимални ниво за садржај';
@@ -59,85 +59,80 @@ $lang['maxseclevel']           = 'Максималан број секција 
 $lang['camelcase']             = 'Користи CamelCase за линкове';
 $lang['deaccent']              = 'Чисти имена страница';
 $lang['useheading']            = 'Преузми наслов првог нивоа за назив странице';
-$lang['refcheck']              = 'Провери референце медијских датотека';
-$lang['refshow']               = 'Број референци које се приказују за медијске датотеке';
-$lang['allowdebug']            = 'Укључи дебаговање <b>искључи ако није потребно!</b>';
-$lang['usewordblock']          = 'Блокирај спам на основу листе речи';
-$lang['indexdelay']            = 'Одлагање индексирања (секунде)';
-$lang['relnofollow']           = 'Користи rel="nofollow" за спољне линкове';
-$lang['mailguard']             = 'Замутити Е-адресе';
-$lang['iexssprotect']          = 'Провера потенцијално малициозног кода у Јаваскрипт или ХТМЛ коду';
-$lang['showuseras']            = 'Шта приказати за исписивање корисника који је последњи вршио измене';
+$lang['sneaky_index']          = 'По инсталацији DokuWiki ће у индексу приказати све именске просторе. Укључивањем ове опције именски простори у којима корисник нема право читања ће бити сакривени. Консеквенца је да ће и доступни подпростори бити сакривени. Ово доводи до неупотребљивости Права приступа у неким поставкама.';
+$lang['hidepages']             = 'Сакриј подударне странице (на основу регуларних израза)';
 $lang['useacl']                = 'Користи листу права приступа';
 $lang['autopasswd']            = 'Аутогенерисане лозинки';
 $lang['authtype']              = 'Позадински систем аутентификације';
-$lang['passcrypt']             = 'Метода енкрипције лозинки';
+$lang['passcrypt']             = 'Метода шифровања лозинки';
 $lang['defaultgroup']          = 'Подразумевана група';
 $lang['superuser']             = 'Суперкорисник - група, корисник или зарезом одвојена листа корисника корисник1,@група1,корисник2 са отвореним проступом свим страницама и функцијама без обзира на поставке Контроле приступа';
 $lang['manager']               = 'Управник - група, корисник или зарезом одвојена листа корисника корисник1,@група1,корисник2 са отвореним проступом неким функцијама за управљање';
 $lang['profileconfirm']        = 'Потврди промене у профилу куцањем лозинке';
+$lang['rememberme']            = 'Дозволи стални колачић за пријављивање (запамти ме)';
 $lang['disableactions']        = 'Искључи DokuWiki наредбе';
 $lang['disableactions_check']  = 'Провера';
 $lang['disableactions_subscription'] = 'Претплата';
 $lang['disableactions_wikicode'] = 'Прикажи извор/Извези сирово';
 $lang['disableactions_other']  = 'Остале наредбе (раздвојене зарезом)';
-$lang['sneaky_index']          = 'По инсталацији DokuWiki ће у индексу приказати све именске просторе. Укључивањем ове опције именски простори у којима корисник нема право читања ће бити сакривени. Консеквенца је да ће и доступни подпростори бити сакривени. Ово доводи до неупотребљивости Права приступа у неким поставкама.';
 $lang['auth_security_timeout'] = 'Временска пауза у аутентификацији (секунде)';
 $lang['securecookie']          = 'Да ли колачићи који су постављени преко ХТТПС треба слати веб читачу само преко ХТТПС? Искључите ову опцију само ако је пријављивање на вики заштићено ССЛом а остали део викија незаштићен.';
-$lang['updatecheck']           = 'Провера надоградњи и сигурносних упозорења? Dokuwiki мора да контактира update.dokuwiki.org ради добијања информација.';
-$lang['userewrite']            = 'Направи леп УРЛ';
-$lang['useslash']              = 'Користи косу црту у УРЛу за раздвајање именских простора ';
+$lang['usewordblock']          = 'Блокирај спам на основу листе речи';
+$lang['relnofollow']           = 'Користи rel="nofollow" за спољне линкове';
+$lang['indexdelay']            = 'Одлагање индексирања (секунде)';
+$lang['mailguard']             = 'Замутити Е-адресе';
+$lang['iexssprotect']          = 'Провера потенцијално малициозног кода у Јаваскрипт или ХТМЛ коду';
 $lang['usedraft']              = 'Аутоматски сачувај скицу у току писања измена';
-$lang['sepchar']               = 'Раздвајање речи у називу странице';
-$lang['canonical']             = 'Користи правилне УРЛове';
-$lang['fnencode']              = 'Метод кодирања не-ASCII имена фајлова:';
-$lang['autoplural']            = 'Провери облик множине у линковима';
-$lang['compression']           = 'Метод компресије за attic датотеке';
-$lang['cachetime']             = 'Максимално трајање оставе (сек)';
+$lang['htmlok']                = 'Дозволи угњежђени ХТМЛ';
+$lang['phpok']                 = 'Дозволи угњежђени ПХП';
 $lang['locktime']              = 'МАксимално трајање закључавања датотека (сек)';
-$lang['fetchsize']             = 'Максимална величина (у бајтима) коју може да преузме fetch.php од споља';
-$lang['notify']                = 'Пошаљи обавештења о променама на ову е-адресу';
-$lang['registernotify']        = 'Пошаљи обавештење о новорегистрованим корисницима на ову е-адресу';
-$lang['mailfrom']              = 'Е-адреса која се користи као пошиљаоц за аутоматске е-поруке';
-$lang['gzip_output']           = 'Користи гзип шифрирање за иксХТМЛ';
-$lang['gdlib']                 = 'ГД Либ верзија';
-$lang['im_convert']            = 'Путања до алатке за коверзију ИмиџМеџик ';
-$lang['jpg_quality']           = 'ЈПГ квалитет компресије (0-100)';
-$lang['subscribers']           = 'Укључи могућност претплате за странице';
-$lang['subscribe_time']        = 'Време након ког се спискови претплатника и сижеи шаљу (у секундама); Ова цифра би требало да буде мања од цифре наведене под recent_days';
-$lang['compress']              = 'Сажимај ЦСС и јаваскрипт';
-$lang['hidepages']             = 'Сакриј подударне странице (на основу регуларних израза)';
-$lang['send404']               = 'Пошаљи поруку "ХТТП 404/Страница не постоји" за непостојеће странице';
-$lang['sitemap']               = 'Генериши Гугл мапу сајта (дан)';
-$lang['broken_iua']            = 'Да ли је функција ignore_user_abort function не ради на вашем систему? Ово може проузроковати неиндексирање података за претрагу. ИИС+ПХП/ЦГИ је често ван функције. Погледајте <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">баг 852</a> за више информација.';
-$lang['xsendfile']             = 'Користи заглавље X-Sendfile да би веб сервер могао да испоручује статичке датотеке? Веб сервер треба да подржава ову функцију.';
-$lang['renderer_xhtml']        = 'Исцртавање користи главни (xhtml) вики испис';
-$lang['renderer__core']        = '%s (dokuwiki језгро)';
-$lang['renderer__plugin']      = '%s (додатак)';
-$lang['rememberme']            = 'Дозволи стални колачић за пријављивање (запамти ме)';
-$lang['rss_type']              = 'Врста ИксМЛ довода';
-$lang['rss_linkto']            = 'ИксМЛ довод линкује на';
-$lang['rss_content']           = 'Шта треба приказати у ИксМЛ доводу?';
-$lang['rss_update']            = 'ИксМЛ';
-$lang['recent_days']           = 'Колико последњих промена чувати (дани)';
-$lang['rss_show_summary']      = 'ИксМЛ довод приказује збир у наслову';
+$lang['cachetime']             = 'Максимално трајање оставе (сек)';
 $lang['target____wiki']        = 'Циљни прозор за интерне линкове';
 $lang['target____interwiki']   = 'Циљни прозор за међувики линкове';
 $lang['target____extern']      = 'Циљни прозор за спољне линкове';
 $lang['target____media']       = 'Циљни прозор за медијске линкове';
 $lang['target____windows']     = 'Циљни прозор за Виндоуз линкове';
+$lang['refcheck']              = 'Провери референце медијских датотека';
+$lang['gdlib']                 = 'ГД Либ верзија';
+$lang['im_convert']            = 'Путања до алатке за коверзију ИмиџМеџик ';
+$lang['jpg_quality']           = 'ЈПГ квалитет компресије (0-100)';
+$lang['fetchsize']             = 'Максимална величина (у бајтима) коју може да преузме fetch.php од споља';
+$lang['subscribers']           = 'Укључи могућност претплате за странице';
+$lang['subscribe_time']        = 'Време након ког се спискови претплатника и сижеи шаљу (у секундама); Ова цифра би требало да буде мања од цифре наведене под recent_days';
+$lang['notify']                = 'Пошаљи обавештења о променама на ову е-адресу';
+$lang['registernotify']        = 'Пошаљи обавештење о новорегистрованим корисницима на ову е-адресу';
+$lang['mailfrom']              = 'Е-адреса која се користи као пошиљаоц за аутоматске е-поруке';
+$lang['sitemap']               = 'Генериши Гугл мапу сајта (дан)';
+$lang['rss_type']              = 'Врста ИксМЛ довода';
+$lang['rss_linkto']            = 'ИксМЛ довод линкује на';
+$lang['rss_content']           = 'Шта треба приказати у ИксМЛ доводу?';
+$lang['rss_update']            = 'ИксМЛ';
+$lang['rss_show_summary']      = 'ИксМЛ довод приказује збир у наслову';
+$lang['updatecheck']           = 'Провера надоградњи и сигурносних упозорења? Dokuwiki мора да контактира update.dokuwiki.org ради добијања информација.';
+$lang['userewrite']            = 'Направи леп УРЛ';
+$lang['useslash']              = 'Користи косу црту у УРЛу за раздвајање именских простора ';
+$lang['sepchar']               = 'Раздвајање речи у називу странице';
+$lang['canonical']             = 'Користи правилне УРЛове';
+$lang['fnencode']              = 'Метод кодирања не-ASCII имена фајлова:';
+$lang['autoplural']            = 'Провери облик множине у линковима';
+$lang['compression']           = 'Метод компресије за attic датотеке';
+$lang['gzip_output']           = 'Користи гзип шифрирање за иксХТМЛ';
+$lang['compress']              = 'Сажимај ЦСС и јаваскрипт';
+$lang['send404']               = 'Пошаљи поруку "ХТТП 404/Страница не постоји" за непостојеће странице';
+$lang['broken_iua']            = 'Да ли је функција ignore_user_abort function не ради на вашем систему? Ово може проузроковати неиндексирање података за претрагу. ИИС+ПХП/ЦГИ је често ван функције. Погледајте <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">баг 852</a> за више информација.';
+$lang['xsendfile']             = 'Користи заглавље X-Sendfile да би веб сервер могао да испоручује статичке датотеке? Веб сервер треба да подржава ову функцију.';
+$lang['renderer_xhtml']        = 'Исцртавање користи главни (xhtml) вики испис';
+$lang['renderer__core']        = '%s (dokuwiki језгро)';
+$lang['renderer__plugin']      = '%s (додатак)';
+$lang['jquerycdn_o_0']         = 'Без CDN-a, само локална достава';
+$lang['jquerycdn_o_jquery']    = 'CDN на адреси code.jquery.com';
+$lang['jquerycdn_o_cdnjs']     = 'CDN на cdnjs.com';
 $lang['proxy____host']         = 'Назив посредника (проксија)';
 $lang['proxy____port']         = 'Порт посредника (проксија)';
 $lang['proxy____user']         = 'Корисничко име на посреднику (проксију)';
 $lang['proxy____pass']         = 'Лозинка на посреднику (проксију)';
 $lang['proxy____ssl']          = 'Користи ССЛ за повезивање са посредником (проксијем)';
 $lang['proxy____except']       = 'Редован израз који би требало да се подудара са веб адресом странице за коју треба прескочити посредника (прокси).';
-$lang['safemodehack']          = 'Укључи преправку за безбедни режим';
-$lang['ftp____host']           = 'ФТП сервер за безбедни режим';
-$lang['ftp____port']           = 'ФТП порт за безбедни режим';
-$lang['ftp____user']           = 'ФТП корисничко име за безбедни режим';
-$lang['ftp____pass']           = 'ФТП лозинка за безбедни режим';
-$lang['ftp____root']           = 'ФТП основна фасцикла за безбедни режим';
 $lang['license_o_']            = 'Није одабрано';
 $lang['typography_o_0']        = 'не';
 $lang['typography_o_1']        = 'Само дупли наводници';
@@ -173,6 +168,7 @@ $lang['xsendfile_o_2']         = 'Стандардно заглавље X-Sendfi
 $lang['xsendfile_o_3']         = 'Власничко заглавље Nginx X-Accel-Redirect';
 $lang['showuseras_o_loginname'] = 'Корисничко име';
 $lang['showuseras_o_username'] = 'Име и презиме корисника';
+$lang['showuseras_o_username_link'] = 'Пуно име корисника као корисничка веза међувикија';
 $lang['showuseras_o_email']    = 'Е-адреса (замућено по подешавањима mailguard-а)';
 $lang['showuseras_o_email_link'] = 'Корисничка Е-адреса као mailto: веза';
 $lang['useheading_o_0']        = 'Никада';
