@@ -161,7 +161,7 @@ function currentHeadlineLevel(textboxId){
     var field = jQuery('#' + textboxId)[0],
         s = false,
         opts = [field.value.substr(0,DWgetSelection(field).start)];
-    if (field.form.prefix) {
+    if (field.form && field.form.prefix) {
         // we need to look in prefix context
         opts.push(field.form.prefix.value);
     }
@@ -238,7 +238,7 @@ jQuery(function () {
         sel.start = 0;
         sel.end   = 0;
         DWsetSelection(sel);
-        $edit_text.focus();
+        $edit_text.trigger('focus');
 
         doku_edit_text_content = $edit_text.val();
     }
@@ -260,13 +260,13 @@ jQuery(function () {
     window.onunload = deleteDraft;
 
     // reset change memory var on submit
-    jQuery('#edbtn__save').click(
+    jQuery('#edbtn__save').on('click',
         function() {
             window.onbeforeunload = '';
             textChanged = false;
         }
     );
-    jQuery('#edbtn__preview').click(
+    jQuery('#edbtn__preview').on('click',
         function() {
             window.onbeforeunload = '';
             textChanged = false;
@@ -275,8 +275,7 @@ jQuery(function () {
     );
 
     var $summary = jQuery('#edit__summary');
-    $summary.change(doku_summaryCheck);
-    $summary.keyup(doku_summaryCheck);
+    $summary.on('change keyup', doku_summaryCheck);
 
     if (textChanged) doku_summaryCheck();
 });
