@@ -107,7 +107,7 @@ var dw_mediamanager = {
 
         dw_mediamanager.update_resizable();
         dw_mediamanager.layout_width = $page.width();
-        jQuery(window).resize(dw_mediamanager.window_resize);
+        jQuery(window).on('resize', dw_mediamanager.window_resize);
     },
 
     init_options: function () {
@@ -194,7 +194,7 @@ var dw_mediamanager = {
                     .addClass('button')
                     .attr('id', "media__" + opt.id + "btn" + (i + 1))
                     .attr('title', LANG['media' + text])
-                    .click(bind(dw_mediamanager.setOpt, opt.id));
+                    .on('click', bind(dw_mediamanager.setOpt, opt.id));
 
                 $img = jQuery(document.createElement('img'))
                     .attr('src', DOKU_BASE + 'lib/images/media_' + opt.id + '_' + text + '.png');
@@ -474,7 +474,7 @@ var dw_mediamanager = {
         if ($container.length === 0) {
             $container = $content;
         }
-        $container.html('<img src="' + DOKU_BASE + 'lib/images/loading.gif" alt="..." class="load" />');
+        $container.html('<img src="' + DOKU_BASE + 'lib/images/throbber.gif" alt="..." class="load" />');
     },
 
     window_resize: function () {
@@ -696,6 +696,14 @@ var dw_mediamanager = {
     prepare_content: function ($content) {
         // hide syntax example
         $content.find('div.example:visible').hide();
+        // toggle list of allowed mime types
+        $content.find('a.allowedmime').on('click', function (event) {
+            event.preventDefault();
+            $toggle = jQuery(this);
+            $list = $toggle.next('span');
+            $list.toggle();
+        }).next('span').hide();
+
     },
 
     /**
@@ -735,7 +743,7 @@ var dw_mediamanager = {
 
         // remove old callback from the insert button and set the new one.
         var $sendbtn = jQuery('#media__sendbtn');
-        $sendbtn.off().click(bind(dw_mediamanager.insert, id));
+        $sendbtn.off().on('click', bind(dw_mediamanager.insert, id));
 
         dw_mediamanager.unforbid('ext');
         if (ext === '.swf') {
@@ -801,7 +809,7 @@ var dw_mediamanager = {
                 $box = jQuery(document.createElement('input'))
                     .attr('type', 'checkbox')
                     .attr('id', 'media__' + opt[0])
-                    .click(bind(dw_mediamanager.toggleOption, opt[0]));
+                    .on('click', bind(dw_mediamanager.toggleOption, opt[0]));
 
                 if (DokuCookie.getValue(opt[0])) {
                     $box.prop('checked', true);
