@@ -7,12 +7,12 @@
  */
 // must be run from within DokuWiki
 if (!defined('DOKU_INC')) die();
+header('X-UA-Compatible: IE=edge,chrome=1');
 
 ?><!DOCTYPE html>
 <html lang="<?php echo $conf['lang']?>" dir="<?php echo $lang['direction'] ?>" class="popup no-js">
 <head>
     <meta charset="utf-8" />
-    <!--[if IE]><meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1" /><![endif]-->
     <title>
         <?php echo hsc($lang['mediaselect'])?>
         [<?php echo strip_tags($conf['title'])?>]
@@ -25,7 +25,6 @@ if (!defined('DOKU_INC')) die();
 </head>
 
 <body>
-    <!--[if lte IE 7 ]><div id="IE7"><![endif]--><!--[if IE 8 ]><div id="IE8"><![endif]-->
     <div id="media__manager" class="dokuwiki">
         <?php html_msgarea() ?>
         <div id="mediamgr__aside"><div class="pad">
@@ -41,6 +40,5 @@ if (!defined('DOKU_INC')) die();
             <?php tpl_mediaContent() ?>
         </div></div>
     </div>
-    <!--[if ( lte IE 7 | IE 8 ) ]></div><![endif]-->
 </body>
 </html>
